@@ -1,9 +1,9 @@
-/*
+/**
  * @file cmdlog.c
- * @brief R}hO
+ * @brief コマンドログ
  * @author BananaJinn
- * @version $Id: cmdlog.c,v 1.17 2007/10/02 15:10:52 bananajinn Exp $
- * ~Օʉ
+ * @version $Id: cmdlog.c,v 1.20 2010/11/01 14:34:11 bananajinn Exp $
+ * 円盤複写屋
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
 
@@ -22,6 +22,8 @@
 #include "cmd.h"
 #include "cmdlog.h"
 #include "text.h"
+#include "ui.h"
+#include "ebstring.h"
 
 #define CMDLOGFILE 0
 
@@ -63,14 +65,14 @@ CreateLog(CMDDRIVE *pReader, CMDDRIVE *pWriter, int nWriter)
 		  if(!REALDRIVE(pReader)){
 			continue;
 		  }
-		  fprintf(fp, MSG_READER_ /*"Ǎu : "*/);
+		  fprintf(fp, MSG_READER_ /*"読込装置 : "*/);
 		  pDrive = pReader;
 		}
 		else{
 		  if(!REALDRIVE(&pWriter[nDrive-1])){
 			continue;
 		  }
-		  fprintf(fp, MSG_WRITER_ /*"u%d : "*/, nDrive);
+		  fprintf(fp, MSG_WRITER_ /*"書込装置%d : "*/, nDrive);
 		  pDrive = &pWriter[nDrive-1];
 		}
 
@@ -106,7 +108,7 @@ CreateLog(CMDDRIVE *pReader, CMDDRIVE *pWriter, int nWriter)
 			   pDrive->cmdlog[nPos].data!=NULL){
 				fprintf(fp, "  DATA%s %ldbyte(s)\n",
 						pDrive->cmdlog[nPos].reqflag==REQ_DATAIN ? "IN" : "OUT",
-						pDrive->cmdlog[nPos].datalen);
+						(long)pDrive->cmdlog[nPos].datalen);
 				nDataLen = pDrive->cmdlog[nPos].datalen;
 				if(nDataLen > pDrive->cmdlog_maxdatalen)
 					nDataLen = pDrive->cmdlog_maxdatalen;
@@ -126,6 +128,12 @@ CreateLog(CMDDRIVE *pReader, CMDDRIVE *pWriter, int nWriter)
 	}
 	fclose(fp);
 
+	{
+		char *message = EbStringNewWithFormat(MSG_CMDLOG_WAS_SAVED_TO_, path);
+		UIDispMessage(message, UIDMT_INFORMATION);
+		EbStringFree(message);
+	}
+	
 	return RET_OK;
 }
 
