@@ -2,7 +2,7 @@
  * @file copydisc.c
  * @brief ~Ղ𕡎
  * @author BananaJinn
- * @version $Id: copydisc.c,v 1.65 2008/11/07 13:23:16 bananajinn Exp $
+ * @version $Id: copydisc.c,v 1.70 2010/11/01 14:34:11 bananajinn Exp $
  * ~Օʉ
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
@@ -30,8 +30,8 @@
 #include "log.h"
 #include "discinfo.h"
 #include "offsetiso.h"
-
-#define SEND_GAPDATA 1
+#include "ebstring.h"
+#include "cuesheet.h"
 
 static DWORD g_SpeedData[10];
 static int g_NumSpeedData=0;
@@ -58,7 +58,7 @@ static void DispSpeed(DWORD lba, DWORD rest_blocks, DWORD total_rest,
 {
 	double blocks_per_sec;
 	double curr_speed;
-	char info[256];
+	char *info = NULL;
 	DWORD rest_time;
 	int ret;
 	double buffer_capacity;
@@ -78,22 +78,26 @@ static void DispSpeed(DWORD lba, DWORD rest_blocks, DWORD total_rest,
 	if(GetOption()->flags & OPFLG_DVD){
 		curr_speed = blocks_per_sec*2048/1024.0/1385;
 	}
+	else if(GetOption()->flags & OPFLG_BD){
+		curr_speed = blocks_per_sec*2048/1024.0/4495;
+	}
 	else{
 		curr_speed = blocks_per_sec*2352/1000.0/176.4;
 	}
 
-	snprintf(info, sizeof(info), MSG_SPEED_ /* "%.1fx"*/, curr_speed);
+	info = EbStringNewWithFormat(MSG_SPEED_ /* "%.1fx"*/, curr_speed);
 	/* c莞ԌvZ(݃gbN) */
 	rest_time = (DWORD)(0.5+rest_blocks/blocks_per_sec);
-	snprintf(info+strlen(info), sizeof(info)-strlen(info),
-			 MSG_REMAINS_ /*" remains=%d:%02d"*/,
-			 (int)(rest_time/60), (int)(rest_time%60));
+	info = EbStringAppendWithFormat(info,
+									MSG_REMAINS_ /*" remains=%d:%02d"*/,
+									(int)(rest_time/60), (int)(rest_time%60));
 	if(total_rest > 0){
 		/* c莞ԌvZ(S) */
 		rest_time = (DWORD)(0.5+total_rest/blocks_per_sec);
-		snprintf(info+strlen(info), sizeof(info)-strlen(info),
-				 MSG_TOTAL_REMAINS_ /*" toral_remains=%d:%02d"*/,
-				 (int)(rest_time/60), (int)(rest_time%60));
+		info = EbStringAppendWithFormat(info,
+										MSG_TOTAL_REMAINS_ /*" toral_remains=%d:%02d"*/,
+										(int)(rest_time/60),
+										(int)(rest_time%60));
 	}
 
 	if(REALDRIVE(dst)){
@@ -101,17 +105,19 @@ static void DispSpeed(DWORD lba, DWORD rest_blocks, DWORD total_rest,
 		if(ret == RET_OK){
 			buffer_capacity = 100-
 				100.0*Get4bytes(dst->data_buf+8)/Get4bytes(dst->data_buf+4);
-			sprintf(info+strlen(info), MSG_BUFFER_ /* " buffer=%.1f%%" */, buffer_capacity);
+			info = EbStringAppendWithFormat(info,
+											MSG_BUFFER_ /* " buffer=%.1f%%" */,
+											buffer_capacity);
 		}
 	}
 	UIDispInfo(info);
 	if(src->type == CMDDRVTYPE_NET){
 		NAUIDispInfo(&src->u.net, info);
 	}
+	EbStringFree(info);
 }
 
 
-
 /**
  * DVD-RW/+RWtH[}bg
  * @param[in]	drive	u\
@@ -168,7 +174,7 @@ static int FormatDVD(CMDDRIVE *drive, BYTE type, DWORD size)
 		return ret;
 	}
 
-	if(type==FDFT_QUICK || type==FDFT_QUICKADD || type==FDFT_QUICKGROW)
+	if(type==FDFT_DVDQUICK || type==FDFT_DVDQUICKADD || type==FDFT_DVDQUICKGROW)
 		message = MSG_MIN_FORMAT;  /*  */
 	else
 		message = MSG_FORMATTING;  /*  */
@@ -192,12 +198,22 @@ static int Formatting(CMDDRIVE *drive)
 {
 	int ret;
 	struct _DISCINFO *di;
+	BYTE format_type = 0;
 
 	if(!REALDRIVE(drive)){
 		return RET_OK;
 	}
 
-	if(drive->disc_type!=DT_DVDPRW){
+	switch(drive->disc_type){
+	case DT_DVDPRW:
+		format_type = FDFT_DVDPRW;
+		break;
+	case DT_BDRE:
+		format_type = FDFT_BDRESPARE;
+		break;
+	}
+	
+	if(format_type == 0){
 		return RET_OK;
 	}
 
@@ -212,7 +228,7 @@ static int Formatting(CMDDRIVE *drive)
 		return RET_OK;
 	}
 
-	ret = FormatDVD(drive, FDFT_DVDPRW, 0xffffffff);
+	ret = FormatDVD(drive, format_type, 0xffffffff);
 	if(ret!=RET_OK){
 		return ret;
 	}
@@ -241,6 +257,10 @@ static int Blanking(CMDDRIVE *drive)
 			return RET_OK;
 		}
 	}
+	if(drive->disc_type==DT_BDRE){
+		/* QuickFormat */
+		return RET_OK;
+	}
 	if(drive->disc_type==DT_DVDPRW){
 		/* sv */
 		return RET_OK;
@@ -332,6 +352,12 @@ static int CloseSession(CMDDRIVE *drive, int num_drv)
 	}
 
 	for(index=0; index<num_drv; index++){
+		if(drive[index].disc_type == DT_BDRE ||
+		   drive[index].disc_type == DT_BDR ||
+		   drive[index].disc_type == DT_DVDPR ||
+		   drive[index].disc_type == DT_DVDPRW){
+			continue;
+		}
 		ret = SendCloseTrackSession(&drive[index], 1, CTST_CLOSESESSION, 0);
 		if(ret!=RET_OK){
 			DispCommandError(&drive[index]);
@@ -428,6 +454,7 @@ static int ReserveTrack(CMDDRIVE *drive, DWORD size)
 	if(!REALDRIVE(drive))
 		return RET_OK;
 
+	DebugLog("Reserve Track/RZone. size=0x%08lx\n", size);
 	ret = SendReserveTrack(drive, size);
 	if(ret!=RET_OK){
 		DispCommandError(drive);
@@ -460,8 +487,7 @@ static int SetWriteParametersPage(CMDDRIVE *drive, CPDISCINFO *discinfo,
 	if(track_num==0)
 		track_num=1;
 	cpti = &discinfo->trackinfo[track_num-1];
-	sess_num = (WORD)cpti->trackinfo.session_number_msb<<8 |
-		(WORD)cpti->trackinfo.session_number_lsb;
+	sess_num = SESSION_NUMBER(&cpti->trackinfo);
 
 	/* ݒl擾ĕKvȕ */
 	ret = SendModeSense(drive, MSPC_CURRENT, 5);
@@ -471,65 +497,67 @@ static int SetWriteParametersPage(CMDDRIVE *drive, CPDISCINFO *discinfo,
 	}
 	mp05 = (struct _MODEPAGE05 *)(drive->data_buf +
 								  (drive->cmd_type==CMDDRVCTYPE_ATAPI ? 8 : 16));
-
-	if(DT_DVD_FAMILY(drive->disc_type)){
-		mp05->write_type = MP05WT_PACKET;
-		mp05->track_mode = MP05TM_DATA;
-		mp05->dbtype = MP05DBT_MODE1;
-	}
-	else{
-		mp05->track_mode = cpti->trackinfo.track_mode;
-		if(IS_TRACKMODE_DATA(mp05->track_mode)){
-			mp05->dbtype = cpti->mode2 ? MP05DBT_MIX : MP05DBT_MODE1;
-			mp05->write_type = cpti->trackinfo.packet ? MP05WT_PACKET : MP05WT_TAO;
+	if(drive->disc_type != DT_BDR &&
+	   drive->disc_type != DT_BDRE){
+		if(DT_DVD_FAMILY(drive->disc_type)){
+			mp05->write_type = MP05WT_PACKET;
+			mp05->track_mode = MP05TM_DATA;
+			mp05->dbtype = MP05DBT_MODE1;
 		}
 		else{
-			mp05->dbtype = MP05DBT_CDDA_2352;
-			mp05->write_type = MP05WT_TAO;
-			Set2bytes(mp05->audio_pause_len, cpti->pause_len);
+			mp05->track_mode = cpti->trackinfo.track_mode;
+			if(IS_TRACKMODE_DATA(mp05->track_mode)){
+				mp05->dbtype = cpti->mode2 ? MP05DBT_MIX : MP05DBT_MODE1;
+				mp05->write_type = cpti->trackinfo.packet ? MP05WT_PACKET : MP05WT_TAO;
+			}
+			else{
+				mp05->dbtype = MP05DBT_CDDA_2352;
+				mp05->write_type = MP05WT_TAO;
+				Set2bytes(mp05->audio_pause_len, cpti->pause_len);
+			}
+		}
+
+		mp05->BUFE = GetOption()->bufe;
+		mp05->test_write = GetOption()->test_write;
+		if(discinfo->sessions == sess_num){
+			/* ŏIZbV */
+			mp05->multi_session = discinfo->disc_stat==DISCSTAT_COMPLETE ? 0 : 3;
+		}
+		else{
+			mp05->multi_session = 3;
+		}
+		mp05->fp = cpti->trackinfo.fp;
+		mp05->copy = cpti->trackinfo.copy;
+		mp05->session_format = discinfo->disc_type;
+		memcpy(mp05->packet_size, cpti->trackinfo.packet_size, 4);
+
+		if(sao){
+			mp05->write_type = MP05WT_SAO;
+			mp05->track_mode = MP05TM_DATA;
+			mp05->fp = 0;
+			Set4bytes(mp05->packet_size, 0UL);
+		}
+
+		/* MCN */
+		if(strlen((char *)discinfo->media_catalog_number)>0){
+			memcpy(mp05->media_cat_number, discinfo->media_catalog_number, 13);
+			mp05->mc_val = 1;
+		}
+		else{
+			memset(mp05->media_cat_number, 0, 13);
+			mp05->mc_val = 0;
+		}
+		/* ISRC */
+		if(strlen((char *)cpti->isrc)>0){
+			memcpy(mp05->ISRC, cpti->isrc, 12);
+			mp05->tc_val = 1;
+		}
+		else{
+			memset(mp05->ISRC, 0, 12);
+			mp05->tc_val = 0;
 		}
 	}
-
-	mp05->BUFE = GetOption()->bufe;
-	mp05->test_write = GetOption()->test_write;
-	if(discinfo->sessions == sess_num){
-		/* ŏIZbV */
-		mp05->multi_session = discinfo->disc_stat==DISCSTAT_COMPLETE ? 0 : 3;
-	}
-	else{
-		mp05->multi_session = 3;
-	}
-	mp05->fp = cpti->trackinfo.fp;
-	mp05->copy = cpti->trackinfo.copy;
-	mp05->session_format = discinfo->disc_type;
-	memcpy(mp05->packet_size, cpti->trackinfo.packet_size, 4);
-
-	if(sao){
-		mp05->write_type = MP05WT_SAO;
-		mp05->track_mode = MP05TM_DATA;
-		mp05->fp = 0;
-		Set4bytes(mp05->packet_size, 0UL);
-	}
-
-	/* MCN */
-	if(strlen((char *)discinfo->media_catalog_number)>0){
-		memcpy(mp05->media_cat_number, discinfo->media_catalog_number, 13);
-		mp05->mc_val = 1;
-	}
-	else{
-		memset(mp05->media_cat_number, 0, 13);
-		mp05->mc_val = 0;
-	}
-	/* ISRC */
-	if(strlen((char *)cpti->isrc)>0){
-		memcpy(mp05->ISRC, cpti->isrc, 12);
-		mp05->tc_val = 1;
-	}
-	else{
-		memset(mp05->ISRC, 0, 12);
-		mp05->tc_val = 0;
-	}
-  
+	
 	ret = SendModeSelect(drive, 5);
 	if(ret!=RET_OK){
 		DispCommandError(drive);
@@ -556,7 +584,7 @@ static int GetVPSize(CMDDRIVE *drive, DWORD lba, DWORD *size_ret)
 	int ret;
 
 	if(!REALDRIVE(drive)){
-		if(drive->type == CMDDRVTYPE_ISO){
+		if(drive->type == CMDDRVTYPE_ISO || drive->type == CMDDRVTYPE_MKISOFS){
 			return RET_OK;
 		}
 		else{
@@ -602,7 +630,7 @@ static int SetVPSize(CMDDRIVE *drive, DWORD size)
 	int ret;
 
 	if(!REALDRIVE(drive)){
-		if(drive->type == CMDDRVTYPE_ISO){
+		if(drive->type == CMDDRVTYPE_ISO || drive->type == CMDDRVTYPE_MKISOFS){
 			return RET_OK;
 		}
 		else{
@@ -669,8 +697,13 @@ static int ExecRead(CMDDRIVE *src, DWORD lba, DWORD blocksize, DWORD len,
   
 	/* Read */
 	if(!REALDRIVE(src)){
-		ret = ReadImageFile(&src->u.image, src->data_buf, blocksize*len,
-							(src->type==CMDDRVTYPE_IMAGE) ? TRUE:FALSE);
+		if(src->type == CMDDRVTYPE_MKISOFS){
+			ret = MIFRead(&src->u.mkisofs, src->data_buf, blocksize*len);
+		}
+		else{
+			ret = ReadImageFile(&src->u.image, src->data_buf, blocksize*len,
+								(src->type==CMDDRVTYPE_IMAGE) ? TRUE:FALSE);
+		}
 		if(ret!=RET_OK)
 			return ret;
 	}
@@ -765,7 +798,7 @@ static int ExecReadWrite(CMDDRIVE *src, CMDDRIVE *dst, int num_dst,
 	int ret=RET_OK;
 	int index;
 	int retry=0;
-	char info[80];
+	char *info = NULL;
 	BYTE rdretry_keep=0;
 	DWORD offset = 0;
 
@@ -776,7 +809,7 @@ static int ExecReadWrite(CMDDRIVE *src, CMDDRIVE *dst, int num_dst,
 		if(GetOption()->outside){
 			offset = GetOffset();
 		}
-		for(retry=0; retry<=300/*32*/; retry++){ /* BANANA */
+		for(retry=0; retry<=32; retry++){
 			if(retry > 0){
 				if(rdretry_keep == 0){
 					/* hCuREADgC񐔂𑝂₷ */
@@ -807,8 +840,10 @@ static int ExecReadWrite(CMDDRIVE *src, CMDDRIVE *dst, int num_dst,
 					sleep(1);
 #endif
 				}
-				sprintf(info, MSG_RETRY_ /*"ēǍ:%d"*/, retry);
+				info = EbStringNewWithFormat(
+					MSG_RETRY_ /*"ēǍ:%d"*/, retry);
 				UIDispInfo(info);
+				info = EbStringFree(info);
 				if(UICheckAbort()){
 					ret = RET_ABORT;
 					break;
@@ -928,7 +963,7 @@ static int OpenTrack(CMDDRIVE *drive, CPDISCINFO *discinfo, WORD track_num)
 				/* DVD-R/-RW */
 				if(drive->disc_type!=DT_DVDR && GetOption()->dao==FALSE){
 					ret = FormatDVD(drive,
-									(BYTE)(track_num==1 ? FDFT_QUICK : FDFT_QUICKADD),
+									(BYTE)(track_num==1 ? FDFT_DVDQUICK : FDFT_DVDQUICKADD),
 									0x00000000);
 				}
 				else{
@@ -1344,7 +1379,7 @@ static int CopyTrack(CMDDRIVE *src, CMDDRIVE *dst, int num_dst,
 	DWORD blocksize;
 	DWORD blocks;
 	DWORD lba;
-	char msgbuf[80];
+	char *msgbuf = NULL;
 	int index;
 
 	/* VariablePacketǂ */
@@ -1398,11 +1433,12 @@ static int CopyTrack(CMDDRIVE *src, CMDDRIVE *dst, int num_dst,
 	}
 
 	/* ʕ\ */
-	sprintf(msgbuf, MSG_TRACK_ /*"gbN%d"*/, track_num);
+	msgbuf = EbStringNewWithFormat(MSG_TRACK_ /*"gbN%d"*/, track_num);
 	UIMeter2Initialize(msgbuf);
 	if(src->type==CMDDRVTYPE_NET){
 		NAUIMeter2Initialize(&src->u.net, msgbuf);
 	}
+	msgbuf = EbStringFree(msgbuf);
 
 	if(Get4bytes(cpti->trackinfo.free_blocks) > 0){
 		for(index=0; index<num_dst; index++){
@@ -1438,288 +1474,6 @@ static int CopyTrack(CMDDRIVE *src, CMDDRIVE *dst, int num_dst,
 }
 
 
-/**
- * SAOL^pCueSheet̍쐬
- * @param[in]	drive	u\
- * @param[in]	discinfo  fBXN
- * @param[in]	track_start JngbNԍ
- * @param[out]	cs_ret	쐬CueSheet
- * @param[out]  numcs_ret 쐬CueSheetz̗vf
- * @param[in]   enable_cdtext CD-TEXTLɂ邩ǂ
- * @retval	RET_OK	I
- * @retval	RET_NG	G[
- */
-static int CreateCueSheet(CMDDRIVE *drive, CPDISCINFO *discinfo,
-						  WORD track_start,
-						  struct _CUESHEET **cs_ret, int *numcs_ret,
-						  BOOL enable_cdtext)
-{
-	struct _CUESHEET *cs = NULL, *csp;
-	int cur_cs = 0;
-	int num_cs = 0;
-	DWORD gap_len;
-	WORD sess_num = 0;
-	DWORD nwa;
-	CPTRACKINFO *cpti=NULL, *lcpti=NULL;
-	struct _TRACKINFO *ti;
-	int ret;
-	BOOL gap_2part;
-	BOOL cdtext=FALSE;
-	WORD track_num;
-
-	if(track_start==1 && discinfo->cdtext_size>0 && enable_cdtext)
-		cdtext = TRUE;
-
-	track_num = track_start;
-	cur_cs = 0;
-	num_cs = 0;
-	sess_num = 0;
-	/* NWA擾 */
-	if(!REALDRIVE(drive)){
-		nwa = -150;
-	}
-	else{
-		ret = SendReadTrackInfo(drive, track_num);
-		if(ret!=RET_OK){
-			DispCommandError(drive);
-			return ret;
-		}
-		ti = (struct _TRACKINFO *)drive->data_buf;
-		nwa = Get4bytes(ti->next_writable_addr);
-		if(nwa == (DWORD)0){
-			nwa -= 150;
-		}
-	}
-
-	if(strlen((char *)discinfo->media_catalog_number)!=0){
-		/* Media Catalog Number */
-		DebugLog("CreateCueSheet: Media catalog number.\n");
-		num_cs += 2;
-		cs = (struct _CUESHEET *)MemResize(cs, num_cs * sizeof(struct _CUESHEET));
-		if(cs==NULL)
-			return RET_MEMERR;
-		csp = &cs[cur_cs++];
-		csp->ctladr = CSADR_MCN;
-		memcpy(&csp->tno, discinfo->media_catalog_number, 7);
-		csp = &cs[cur_cs++];
-		csp->ctladr = CSADR_MCN;
-		memcpy(&csp->tno, discinfo->media_catalog_number+7, 7);
-	}
-	
-	cpti = NULL;
-	lcpti = NULL;
-	ret = RET_OK;
-	for( ; track_num <= discinfo->tracks; track_num++){
-		lcpti = cpti;
-		cpti = &discinfo->trackinfo[track_num-1];
-		gap_len = 0;
-		if(sess_num==0){
-			DebugLog("CreateCueSheet: Lead-in.\n");
-			sess_num = (WORD)cpti->trackinfo.session_number_msb<<8 |
-				(WORD)cpti->trackinfo.session_number_lsb;
-				/* Lead-in */
-			num_cs++;
-			cs = (struct _CUESHEET *)MemResize(
-				cs, num_cs * sizeof(struct _CUESHEET));
-			if(cs==NULL)
-				return RET_MEMERR;
-			csp = &cs[cur_cs++];
-			csp->ctladr = IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)
-				? CSCTL_DATA : CSCTL_AUDIO;
-			csp->ctladr |= CSADR_NORMAL;
-			csp->tno = 0;
-			csp->index = 0;
-			csp->dataform = cdtext ? 0x41 : 0x01;
-			csp->scms = 0;
-			if(sess_num >= 2){
-				nwa -= 150;	/* pregap */
-			}
-			LBA2MSF(nwa, &csp->min, &csp->sec, &csp->frame);
-			gap_len = Get4bytes(cpti->trackinfo.track_start) - nwa;
-		}
-		else if(sess_num != ((WORD)cpti->trackinfo.session_number_msb<<8 |
-							 (WORD)cpti->trackinfo.session_number_lsb)){
-			cpti = lcpti;
-			break;
-		}
-
-		if(strlen((char *)cpti->isrc)!=0){
-			/* ISRC */
-			DebugLog("CreateCueSheet: ISRC.\n");
-			num_cs += 2;
-			cs = (struct _CUESHEET *)MemResize(
-				cs, num_cs * sizeof(struct _CUESHEET));
-			if(cs==NULL)
-				return RET_MEMERR;
-			csp = &cs[cur_cs++];
-			csp->ctladr = CSADR_ISRC;
-			csp->tno = (BYTE)track_num;
-			memcpy(&csp->index, cpti->isrc, 6);
-			csp = &cs[cur_cs++];
-			csp->ctladr = CSADR_ISRC;
-			csp->tno = (BYTE)track_num;
-			memcpy(&csp->index, cpti->isrc+6, 6);
-		}
-		gap_2part = FALSE;
-		if(gap_len==0){
-#if 1	/* ̕ǂ? */
-			if(lcpti!=NULL){
-				gap_len = Get4bytes(cpti->trackinfo.track_start) -
-					(Get4bytes(lcpti->trackinfo.track_start) +
-					 Get4bytes(lcpti->trackinfo.track_size));
-				if(IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)){
-					/* DATA */
-					if(!IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode) ||
-					   lcpti->mode2 != cpti->mode2){
-						/* 2part */
-						DebugLog("CreateCueSheet: Two part pregap.(cdda -> data)\n");
-						gap_2part = TRUE;
-					}
-				}
-				else{
-					/* AUDIO */
-					if(IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode)){
-						/* ODATȀꍇ? */
-						DebugLog("CreateCueSheet: Two part pregap.(data -> cdda)\n");
-						gap_2part = TRUE;
-					}
-				}
-			}
-#else
-			if(!IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)){
-				/* AUDIO */
-				gap_len = cpti->pause_len;
-			}
-			else if(lcpti!=NULL){
-				/* DATA  2nd ȍ~ */
-				gap_len = 150;
-				if(!IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode) ||
-				   lcpti->mode2 != cpti->mode2){
-					/* 2part */
-					gap_len = 75+150;
-					gap_2part = TRUE;
-				}
-			}
-#endif
-		}
-		nwa = Get4bytes(cpti->trackinfo.track_start) - gap_len;
-		DebugLog("CreateCueSheet: track=%d gap=%ld nwa=0x%08lX\n",
-				 track_num, gap_len, nwa);
-		if(gap_len>0){
-			/* pre-gap */
-			if(gap_2part && gap_len>150){
-				num_cs++;
-				cs = (struct _CUESHEET *)MemResize(
-					cs, num_cs * sizeof(struct _CUESHEET));
-				if(cs==NULL)
-					return RET_MEMERR;
-				csp = &cs[cur_cs++];
-				csp->ctladr =
-					IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode)
-					? CSCTL_DATA : CSCTL_AUDIO;
-				csp->ctladr |= CSADR_NORMAL;
-				csp->tno = (BYTE)track_num;
-				csp->index = 0;
-#if SEND_GAPDATA
-				if(!IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode)){
-					csp->dataform = 0x00;
-				}
-				else{
-					csp->dataform = lcpti->mode2 ? 0x20 : 0x10;
-				}
-#else
-				if(!IS_TRACKMODE_DATA(lcpti->trackinfo.track_mode)){
-					csp->dataform = 0x01;
-				}
-				else{
-					csp->dataform = lcpti->mode2 ? 0x24 : 0x14;
-				}
-#endif
-				csp->scms = lcpti->trackinfo.copy ? 0x80 : 0;
-				LBA2MSF(nwa, &csp->min, &csp->sec, &csp->frame);
-				nwa += (gap_len-150);
-				gap_len = 150;
-				DebugLog("CreateCueSheet: Pre-gap.\n");
-			}
-			num_cs++;
-			cs = (struct _CUESHEET *)MemResize(
-				cs, num_cs * sizeof(struct _CUESHEET));
-			if(cs==NULL)
-				return RET_MEMERR;
-			csp = &cs[cur_cs++];
-			csp->ctladr = IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)
-				? CSCTL_DATA : CSCTL_AUDIO;
-			csp->ctladr |= CSADR_NORMAL;
-			csp->tno = (BYTE)track_num;
-			csp->index = 0;
-#if SEND_GAPDATA
-			if(!IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)){
-				csp->dataform = 0x00;
-			}
-			else{
-				csp->dataform = cpti->mode2 ? 0x20 : 0x10;
-			}
-#else
-			if(!IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)){
-				csp->dataform = 0x01;
-			}
-			else{
-				csp->dataform = cpti->mode2 ? 0x24 : 0x14;
-			}
-#endif
-			csp->scms = cpti->trackinfo.copy ? 0x80 : 0;
-			LBA2MSF(nwa, &csp->min, &csp->sec, &csp->frame);
-			
-			nwa += gap_len;
-		}
-		/* Audio/Data */
-		num_cs++;
-		cs = (struct _CUESHEET *)MemResize(
-			cs, num_cs * sizeof(struct _CUESHEET));
-		if(cs==NULL)
-			return RET_MEMERR;
-		csp = &cs[cur_cs++];
-		csp->ctladr = IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)
-			? CSCTL_DATA : CSCTL_AUDIO;
-		csp->ctladr |= CSADR_NORMAL;
-		csp->tno = (BYTE)track_num;
-		csp->index = 1;
-		if(!IS_TRACKMODE_DATA(cpti->trackinfo.track_mode))
-			csp->dataform = 0x00;
-		else
-			csp->dataform = cpti->mode2 ? 0x20 : 0x10;
-		csp->scms = cpti->trackinfo.copy ? 0x80 : 0;
-		LBA2MSF(nwa, &csp->min, &csp->sec, &csp->frame);
-		nwa += Get4bytes(cpti->trackinfo.track_size);
-		DebugLog("CreateCueSheet: Track%d.\n", track_num);
-	}
-	/* Lead-out */
-	num_cs++;
-	cs = (struct _CUESHEET *)MemResize(
-		cs, num_cs * sizeof(struct _CUESHEET));
-	if(cs==NULL)
-		return RET_MEMERR;
-	csp = &cs[cur_cs++];
-	csp->ctladr = IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)
-		? CSCTL_DATA : CSCTL_AUDIO;
-	csp->ctladr |= CSADR_NORMAL;
-	csp->tno = 0xAA;
-	csp->index = 1;
-	if(!IS_TRACKMODE_DATA(cpti->trackinfo.track_mode))
-		csp->dataform = 0x01;
-	else
-		csp->dataform = cpti->mode2 ? 0x24 : 0x14;
-	csp->scms = cpti->trackinfo.copy ? 0x80 : 0;
-	LBA2MSF(nwa, &csp->min, &csp->sec, &csp->frame);
-	DebugLog("CreateCueSheet: Lead-out.\n", track_num);
-	
-	*cs_ret = cs;
-	*numcs_ret = num_cs;
-	DebugLog("CreateCueSheet: Done.\n", track_num);
-	return RET_OK;
-}
-
-
 /**
  * 1ZbV
  * @param[in]	src	ǎ摕u\
@@ -1741,7 +1495,7 @@ static int CopySession(CMDDRIVE *src, CMDDRIVE *dst, int num_dst,
 	BOOL done=FALSE;
 	DWORD lba, blocks;
 	DWORD translen, blocksize;
-	char msgbuf[80];
+	char *msgbuf = NULL;
 	int index;
 	BOOL leadin=FALSE;
 
@@ -1844,11 +1598,12 @@ static int CopySession(CMDDRIVE *src, CMDDRIVE *dst, int num_dst,
 		}
 
 		/* ʕ\ */
-		sprintf(msgbuf, MSG_TRACK_ /*"gbN%d"*/, csp->tno);
+		msgbuf = EbStringNewWithFormat(MSG_TRACK_ /*"gbN%d"*/, csp->tno);
 		UIMeter2Initialize(msgbuf);
 		if(src->type==CMDDRVTYPE_NET){
 			NAUIMeter2Initialize(&src->u.net, msgbuf);
 		}
+		msgbuf = EbStringFree(msgbuf);
 
 		if(GetOption()->outside
 		   && (discinfo->outside_offset > 0)
@@ -2075,7 +1830,8 @@ static int ExecCopy(CMDDRIVE *src, CMDDRIVE *dst, int num_dst)
 		if(REALDRIVE(&dst[index])){
 			if(dst[index].disc_type!=DT_DVDRWO &&
 			   dst[index].disc_type!=DT_DVDRWS &&
-			   dst[index].disc_type!=DT_DVDPRW){
+			   dst[index].disc_type!=DT_DVDPRW &&
+			   dst[index].disc_type!=DT_BDRE){
 				/* DVD-RW/+RW łȂꍇAeʃ`FbN */
 				/* WriteParametersPageݒɂăt[ubN
 				   eĂ܂ */
@@ -2108,8 +1864,10 @@ static int ExecCopy(CMDDRIVE *src, CMDDRIVE *dst, int num_dst)
 
 			if(dst[0].disc_type!=DT_DVDR &&
 			   dst[0].disc_type!=DT_DVDRWO &&
-			   dst[0].disc_type!=DT_DVDRWS){
-				/* DVD-R/-RW ȊO DAO  */
+			   dst[0].disc_type!=DT_DVDRWS &&
+			   dst[0].disc_type!=DT_BDR){
+				/* DVD-R/-RW,BD-R ȊO DAO  */
+				DebugLog("DAO disabled.\n");
 				GetOption()->dao = FALSE;
 			}
 		}
@@ -2146,6 +1904,7 @@ static int ExecCopy(CMDDRIVE *src, CMDDRIVE *dst, int num_dst)
 	}
 
 	if(GetOption()->dao){
+		DebugLog("DAO writing.\n");
 		ret = CopyDAO(src, dst, num_dst, &discinfo);
 		if(ret!=RET_OK){
 			MemFree(discinfo.trackinfo);
@@ -2166,6 +1925,7 @@ static int ExecCopy(CMDDRIVE *src, CMDDRIVE *dst, int num_dst)
 			}
 			if((discinfo.trackinfo[track_num-1].tao==FALSE) &&
 			   DT_CD_FAMILY(dst[0].disc_type)){
+				DebugLog("SAO writing.\n");
 				/* SAOL^ */
 				sao = TRUE;
 				ret = CopySession(src, dst, num_dst, &discinfo, &track_num);
@@ -2179,12 +1939,11 @@ static int ExecCopy(CMDDRIVE *src, CMDDRIVE *dst, int num_dst)
 			}
 
 			/* TAOL^ */
+			DebugLog("TAO writing.\n");
 			sao = FALSE;
 			for(; track_num <= discinfo.tracks; track_num++){
 				cpti = &discinfo.trackinfo[track_num-1];
-				if(sess_num !=
-				   ((WORD)cpti->trackinfo.session_number_msb<<8 |
-					(WORD)cpti->trackinfo.session_number_lsb)){
+				if(sess_num != SESSION_NUMBER(&cpti->trackinfo)){
 					/* ̃ZbV͏I */
 					ret = CloseSession(dst, num_dst);
 					if(ret!=RET_OK){
@@ -2281,6 +2040,9 @@ void PostProcess(int retcode, CMDDRIVE *src, CMDDRIVE *dstp, int num_dst)
 							  UIDMT_INFORMATION);
 			}
 			else{
+				for(index=0; index<num_dst; index++){
+					SendStartStop(&dstp[index], 1, 0, 0);	/* SpinDown */
+				}
 				ret = UIDispMessage(MSG_COMPLETE_SUCCESS_AND_EJECT
 									/*"ɏI܂Bro܂?"*/,
 									UIDMT_QUESTION);
@@ -2299,7 +2061,7 @@ void PostProcess(int retcode, CMDDRIVE *src, CMDDRIVE *dstp, int num_dst)
 							  UIDMT_ERROR);
 			}
 			else{
-				ret = UIDispMessage(MSG_ERROR_OCCURRED
+				ret = UIDispMessage(MSG_ERROR_OCCURRED_CMDLOG
 									/*"G[܂BR}hO𐶐܂?"*/,
 									UIDMT_QUESTION);
 				if(ret==UIDMRET_OK){
@@ -2310,6 +2072,39 @@ void PostProcess(int retcode, CMDDRIVE *src, CMDDRIVE *dstp, int num_dst)
 	}
 }
 
+/**
+ * fBXN^Cv̂̎擾
+ * @param[in] disc_type fBXN^CvR[h
+ * @return ̂Ԃ
+ */
+static const char *GetDiscTypeName(BYTE disc_type)
+{
+	const char *name = "UNKNOWN";
+	switch(disc_type){
+	case DT_CDROM:  name = "CD-ROM";  break;
+	case DT_CDR:	name = "CD-R";  break;
+	case DT_CDRW:	name = "CD-RW";  break;
+	case DT_DVDROM:	name = "DVD-ROM";  break;
+	case DT_DVDR:	name = "DVD-R";  break;
+	case DT_DVDRAM:	name = "DVD-RAM";  break;
+	case DT_DVDRWO:	name = "DVD-RW";  break;
+	case DT_DVDRWS: name = "DVD-RW";  break;
+	case DT_DVDRDL:	name = "DVD-R DL";  break;
+	case DT_DVDRDLJ:	name = "DVD-R DL";  break;
+	case DT_DVDRWDL:	name = "DVD-RW DL";  break;
+	case DT_DVDPRW:	name = "DVD+RW";  break;
+	case DT_DVDPR:	name = "DVD+R";  break;
+	case DT_DVDPRWDL:	name = "DVD+RW DL";  break;
+	case DT_DVDPRDL:	name = "DVD+R DL";  break;
+	case DT_BDROM:	name = "BD-ROM";  break;
+	case DT_BDR:	name = "BD-R";  break;
+	case DT_BDRR:	name = "BD-RR";  break;
+	case DT_BDRE:	name = "BD-RE";  break;
+	}
+	return name;
+}
+
+
 /**
  * ǎ摕ȕ
  * @param[in]	reader ǎ摕uID
@@ -2325,7 +2120,14 @@ static int OpenReader(DRIVEID *reader, CMDDRIVE *drive,
 	int ret;
 
 	if(reader->hid == HID_VIRTUAL){
-		if(reader->tid == CMDDRVTYPE_ISO){
+		if(reader->tid == CMDDRVTYPE_MKISOFS){
+			/* tH_ISOC[W */
+			ret = OpenMkisofsDevice(drive, data_buf, bufsize);
+			if(ret != RET_OK){
+				return ret;
+			}
+		}
+		else if(reader->tid == CMDDRVTYPE_ISO){
 			/* ISOC[W */
 			ret = OpenISOImageDevice(drive, TRUE, data_buf, bufsize);
 			if(ret != RET_OK){
@@ -2429,6 +2231,8 @@ static int OpenWriter(DRIVEID *writer, int num_writer,
 			if(ret != RET_OK){
 				continue;
 			}
+			DebugLog("Writer[%d] DiscType=%s(%02X)\n", index,
+					 GetDiscTypeName(tmpdrive.disc_type), tmpdrive.disc_type);
 			memcpy(&drive[*num_writable_drive], &tmpdrive, sizeof(CMDDRIVE));
 			(*num_writable_drive)++;
 		}
