@@ -1,8 +1,8 @@
-/*
+/**
  * @file copydisc.h
  * @brief ~Ղ𕡎
  * @author BananaJinn
- * @version $Id: copydisc.h,v 1.10 2006/05/18 15:23:25 bananajinn Exp $
+ * @version $Id: copydisc.h,v 1.12 2006/09/18 13:59:00 bananajinn Exp $
  * ~Օʉ
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
@@ -24,7 +24,6 @@ extern "C" {
 #endif
 
 extern int CopyDisc(DRIVEID *reader, DRIVEID *writer, int num_writer);
-extern void DebugLog(char *fmt, ...);
 
 #ifdef __cplusplus
 }
