@@ -1,9 +1,9 @@
 /**
  * @file discinfo.c
- * @brief fBXN擾֘A
+ * @brief ディスク情報取得関連
  * @author BananaJinn
- * @version $Id: discinfo.c,v 1.9 2008/06/17 15:22:21 bananajinn Exp $
- * ~Օʉ
+ * @version $Id: discinfo.c,v 1.11 2010/11/02 15:23:51 bananajinn Exp $
+ * 円盤複写屋
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
 #include <stdio.h>
@@ -22,21 +22,21 @@
 #include "log.h"
 #include "discinfo.h"
 #include "emg.h"
-
+#include "ebstring.h"
 
 /**
- * fBXNݒ(C[Wt@CɋL^)
- * @param[in]	drive	u\
- * @param[in]	discinfo  fBXN
- * @retval	RET_OK	I
- * @retval	RET_NG	G[
+ * ディスク情報を設定(イメージファイルに記録する)
+ * @param[in]	drive	書込装置構造体
+ * @param[in]	discinfo  ディスク情報
+ * @retval	RET_OK	正常終了
+ * @retval	RET_NG	エラー
  */
 int SetDiscInformation(CMDDRIVE *drive, CPDISCINFO *discinfo)
 {
 	int ret;
 
 	if(drive->type == CMDDRVTYPE_ISO){
-		/* ISOC[W̏ꍇ́A1gbN/1ZbV̂ */
+		/* ISOイメージの場合は、1トラック/1セッションのみ */
 		if(discinfo->tracks > 1){
 			UIDispMessage(MSG_CANT_CREATE_MULTITRACK_ISO,
 						  UIDMT_ERROR);
@@ -44,25 +44,25 @@ int SetDiscInformation(CMDDRIVE *drive, CPDISCINFO *discinfo)
 		}
 	}
 	else if(drive->type == CMDDRVTYPE_IMAGE){
-		/* ~ՕʉIWiC[W */
-		/* C[Wt@CɃfBXN */
+		/* 円盤複写屋オリジナルイメージ */
+		/* イメージファイルにディスク情報を書き込む */
 		ret = EmgWriteDiscInformation(&drive->u.image, discinfo);
 		if(ret!=RET_OK)
 			return ret;
 	}
-
+	
 	return RET_OK;
 }
 
 
 /**
- * TAOL^ׂǂ𔻕ʂ
- * @param[in]	drive	hCu\
- * @param[in]	discinfo  fBXN\
- * @param[in]	sess_num  ZbVԍ
- * @param[out]	result    ʌ(TAO=TRUE)
- * @retval	RET_OK  I
- * @retval	RET_NG	G[
+ * TAO記録すべきかどうかを判別する
+ * @param[in]	drive	ドライブ構造体
+ * @param[in]	discinfo  ディスク情報構造体
+ * @param[in]	sess_num  セッション番号
+ * @param[out]	result    判別結果(TAO=TRUE)
+ * @retval	RET_OK  正常終了
+ * @retval	RET_NG	エラー
  */
 static int JudgeTAO(CMDDRIVE *drive, CPDISCINFO *discinfo,
 					WORD sess_num, BOOL *result)
@@ -72,20 +72,20 @@ static int JudgeTAO(CMDDRIVE *drive, CPDISCINFO *discinfo,
 
 	*result = FALSE;
 	if(!DT_CD_FAMILY(drive->disc_type)){
-		*result = TRUE;	/* DVDn̏ꍇTAOƂ */
+		*result = TRUE;	/* DVD系の場合はTAOとする */
 		DebugLog("JudgeTAO: TAO(Disc is not CD.)\n");
 		return RET_OK;
 	}
 
 	if(sess_num == discinfo->sessions){
-		/* ŏIZbV̏ꍇ̓I[vZbVǂmF */
+		/* 最終セッションの場合はオープンセッションかどうかを確認 */
 		if(discinfo->last_sess_stat == SESSSTAT_EMPTY){
 			*result = FALSE;
 			DebugLog("JudgeTAO: Session is empty.\n");
 			return RET_OK;
 		}
 		else if(discinfo->last_sess_stat == SESSSTAT_INCOMPLETE){
-			/* ZbV̏ꍇTAOƂ */
+			/* 未完了セッションの場合はTAOとする */
 			*result = TRUE;
 			DebugLog("JudgeTAO: TAO(Last session is incomplete.)\n");
 			return RET_OK;
@@ -93,22 +93,22 @@ static int JudgeTAO(CMDDRIVE *drive, CPDISCINFO *discinfo,
 	}
 
 	/*
-	 * ȑO̓ZbV̍Ō Run-out 邩ǂ𔻕ʂĂA
-	 * ͂ Run-out [hG[ɂȂȂhCuAʂs\!?
-	 * ZbVN[YĂȂASAOŋL^邱ƂɂB
+	 * 以前はセッションの最後に Run-out があるかどうかを判別していたが、
+	 * もはや Run-out がリードエラーにならないドライブもあり、判別が不可能!?
+	 * セッションがクローズされているなら、SAOで記録することにする。
 	 */
 	*result = FALSE;
 	return RET_OK;
 }
 	
 /**
- * w肳ꂽZbṼ[hAEgJnAhX߂B
- * @param[in]	drive	hCu\
- * @param[in]	discinfo  fBXN\
- * @param[in]	sess_num  ZbVԍ
- * @param[out]	lout_start  Lead-outJnAhX
- * @retval	RET_OK  I
- * @retval	RET_NG	G[
+ * 指定されたセッションのリードアウト開始アドレスを求める。
+ * @param[in]	drive	ドライブ構造体
+ * @param[in]	discinfo  ディスク情報構造体
+ * @param[in]	sess_num  セッション番号
+ * @param[out]	lout_start  Lead-out開始アドレス
+ * @retval	RET_OK  正常終了
+ * @retval	RET_NG	エラー
  */
 static int GetLeadOutStart(CMDDRIVE *drive, CPDISCINFO *discinfo,
 						   WORD sess_num, DWORD *lout_start)
@@ -121,7 +121,7 @@ static int GetLeadOutStart(CMDDRIVE *drive, CPDISCINFO *discinfo,
 	WORD sno;
 	CPTRACKINFO *cpti;
 
-	/* TOC񂩂YZbṼ[hAEgJnAhX߂ */
+	/* TOC情報から該当セッションのリードアウト開始アドレスを求める */
 	ret = SendReadToc(drive, sess_num, 1, RTF_FULLTOC);
 	if(ret==RET_OK){
 		for(i=sizeof(struct _TOCHEADER); i<drive->bufsize; i+=sizeof(struct _FULLTOCDESC)){
@@ -133,7 +133,7 @@ static int GetLeadOutStart(CMDDRIVE *drive, CPDISCINFO *discinfo,
 		}
 	}
 	else{
-		/* ReadTOCG[ɂȂꍇ̓gbN񂩂狁߂ */
+		/* ReadTOCがエラーになる場合はトラック情報から求める */
 		for(tno=1; tno<=discinfo->tracks; tno++){
 			cpti = &discinfo->trackinfo[tno-1];
 			sno = (WORD)cpti->trackinfo.session_number_msb<<8 |
@@ -144,23 +144,23 @@ static int GetLeadOutStart(CMDDRIVE *drive, CPDISCINFO *discinfo,
 			}
 		}
 		/*
-		 * Run-outƉ肵Ă +2 B
-		 * ۂɓǂŃAhXG[Ȃ Run-out ͖ƂɂB
+		 * Run-outがあると仮定しておいて +2 する。
+		 * 実際に読んでアドレスエラーなら Run-out は無かったことにする。
 		 */
 		lba += 2;
 	}
   
 	if(lba==0UL){
-		/* 擾łȂ */
+		/* 取得できなかった */
 		*lout_start = lba;
 		return RET_OK;
 	}
   
-	/* [hAEgJnAhX̒O2ubNǂł݂ */
+	/* リードアウト開始アドレスの直前2ブロックを読んでみる */
 	ret = SendReadCD(drive, lba-2, 2);
 	if(ret != RET_OK){
 		if(SD_ASC(drive)==0x21){
-			/* Run-out ͖ */
+			/* Run-out は無かった */
 			lba -= 2;
 		}
 	}
@@ -171,11 +171,11 @@ static int GetLeadOutStart(CMDDRIVE *drive, CPDISCINFO *discinfo,
 }
 
 /**
- * ǎ摕u̎wgbÑvMbv擾
- * @param[in]	drive	ǎ摕u\
- * @param[in/out] cpti	gbN
- * @retval	RET_OK	I
- * @retval	RET_NG	G[
+ * 読取装置の指定トラックのプリギャップ長を取得する
+ * @param[in]	drive	読取装置構造体
+ * @param[in/out] cpti	トラック情報
+ * @retval	RET_OK	正常終了
+ * @retval	RET_NG	エラー
  */
 static int GetGapLen(CMDDRIVE *drive, CPTRACKINFO *cpti)
 {
@@ -186,12 +186,12 @@ static int GetGapLen(CMDDRIVE *drive, CPTRACKINFO *cpti)
 
 	track_start = Get4bytes(cpti->trackinfo.track_start);
 	search_end = track_start;
-	search_start = search_end - 151;	/* GAP=150ʓIȂ̂ŁA̎O猟 */
+	search_start = search_end - 151;	/* GAP長=150が一般的なので、その手前から検索 */
 	real_start = search_start;
 
 	while(TRUE){
 		/*
-		 * QTV[PVŃANZXԂ񑬂
+		 * ２分探索するよりもシーケンシャルでアクセスした方がたぶん速い
 		 */
 		for(lba=search_start; lba<search_end; lba++){
 			ret = GetSubQ(drive, lba, 1);
@@ -200,7 +200,7 @@ static int GetGapLen(CMDDRIVE *drive, CPTRACKINFO *cpti)
 				continue;
 			}
 			if((drive->data_buf[0] & 0x0f)!=0x01){
-				/* ԂISRCMediaCatalogNumberL^Ă */
+				/* たぶんISRCかMediaCatalogNumberが記録されている */
 				search_start++;
 				continue;
 			}
@@ -209,7 +209,7 @@ static int GetGapLen(CMDDRIVE *drive, CPTRACKINFO *cpti)
 			}
 		}
 		if(lba==real_start){
-			/* 擪ɃMbvȂAƑO猟 */
+			/* 検索した先頭が既にギャップなら、もっと前から検索する */
 			search_end = search_start;
 			search_start -= 150;
 			real_start = search_start;
@@ -225,7 +225,7 @@ static int GetGapLen(CMDDRIVE *drive, CPTRACKINFO *cpti)
 		cpti->pause_len = (WORD)(track_start - lba);
 
 	if(cpti->pause_len>0){
-		/* Ô߁AMbv̍ŌmF */
+		/* 念のため、ギャップの最後も確認する */
 		ret = GetSubQ(drive, Get4bytes(cpti->trackinfo.track_start)-1, 1);
 		if(ret==RET_OK){
 			if((drive->data_buf[0] & 0x0f)==0x01 &&
@@ -240,12 +240,12 @@ static int GetGapLen(CMDDRIVE *drive, CPTRACKINFO *cpti)
 }
 
 /**
- * gbN擾
- * @param[in]	drive	ǎ摕u\
- * @param[in]	track_num	gbNԍ
- * @param[out]	cpti	gbN
- * @retval	RET_OK	I
- * @retval	RET_NG	G[
+ * トラック情報取得
+ * @param[in]	drive	読取装置構造体
+ * @param[in]	track_num	トラック番号
+ * @param[out]	cpti	トラック情報
+ * @retval	RET_OK	正常終了
+ * @retval	RET_NG	エラー
  */
 static int GetTrackInformation(CMDDRIVE *drive, WORD track_num, CPTRACKINFO *cpti)
 {
@@ -264,7 +264,7 @@ static int GetTrackInformation(CMDDRIVE *drive, WORD track_num, CPTRACKINFO *cpt
 	if(DT_CD_FAMILY(drive->disc_type)){
 		memset(cpti->isrc, 0, 12+1);
 		if(IS_TRACKMODE_DATA(cpti->trackinfo.track_mode)){
-			/* MODE2ǂ𒲂ׂ */
+			/* MODE2かどうかを調べる */
 			ret = SendReadCD(drive, Get4bytes(cpti->trackinfo.track_start), 1);
 			if(ret!=RET_OK){
 				DispCommandError(drive);
@@ -283,7 +283,7 @@ static int GetTrackInformation(CMDDRIVE *drive, WORD track_num, CPTRACKINFO *cpt
 				memcpy(cpti->isrc, drive->data_buf+9, 12);
 			}
 			if(track_num>1){
-				/* Mbv𒲂ׂ */
+				/* ギャップ長を調べる */
 				ret = GetGapLen(drive, cpti);
 				if(ret!=RET_OK){
 					return ret;
@@ -302,13 +302,13 @@ static int GetTrackInformation(CMDDRIVE *drive, WORD track_num, CPTRACKINFO *cpt
 }
 
 /**
- * gbNTCY𒲐
- * @param[in]	drive	ǎ摕u\
- * @param[in/out] discinfo fBXN
- * @param[in]	track_num  gbNԍ
- * @param[in]	lout_start Lead-outJnAhX
- * @retval	RET_OK	I
- * @retval	RET_NG	G[
+ * トラックサイズを調整する
+ * @param[in]	drive	読取装置構造体
+ * @param[in/out] discinfo ディスク情報
+ * @param[in]	track_num  トラック番号
+ * @param[in]	lout_start Lead-out開始アドレス
+ * @retval	RET_OK	正常終了
+ * @retval	RET_NG	エラー
  */
 static int AdjustTrackSize(CMDDRIVE *drive, CPDISCINFO *discinfo,
 						   WORD track_num, DWORD lout_start)
@@ -330,13 +330,13 @@ static int AdjustTrackSize(CMDDRIVE *drive, CPDISCINFO *discinfo,
 	next_start = lout_start;
 	cpti = &discinfo->trackinfo[track_num-1];
 	if(cpti->tao){
-		/* gbNȂgbN̍Ō2ubNǂł݂ */
+		/* 完了トラックならトラックの最後2ブロックを読んでみる */
 		if(Get4bytes(cpti->trackinfo.free_blocks)==0){
 			lba = Get4bytes(cpti->trackinfo.track_start) + 
 				Get4bytes(cpti->trackinfo.track_size) -2;
 			ret = SendReadCD(drive, lba, 2);
 			if(ret!=RET_OK){
-				/* ǂ߂ȂȂ炽Ԃ Run-out ł傤 */
+				/* 読めないならたぶん Run-out でしょう */
 				track_size = Get4bytes(cpti->trackinfo.track_size) -2;
 				Set4bytes(cpti->trackinfo.track_size, track_size);
 			}
@@ -347,7 +347,7 @@ static int AdjustTrackSize(CMDDRIVE *drive, CPDISCINFO *discinfo,
 		ncpti = &discinfo->trackinfo[track_num];
 		if(((WORD)cpti->trackinfo.session_number_msb<<8 | cpti->trackinfo.session_number_lsb)==
 		   ((WORD)ncpti->trackinfo.session_number_msb<<8 | ncpti->trackinfo.session_number_lsb)){
-			/* ̃gbNZbV */
+			/* 次のトラックも同じセッション */
 			next_start = Get4bytes(ncpti->trackinfo.track_start);
 			if(IS_TRACKMODE_DATA(ncpti->trackinfo.track_mode)){
 				next_start -= 150;
@@ -365,7 +365,7 @@ static int AdjustTrackSize(CMDDRIVE *drive, CPDISCINFO *discinfo,
 	if(next_start==0)
 		return RET_OK;
 
-	/* ۂɓǂ߂Ƃ܂œǂł݂? */
+	/* 実際に読めるとこまで読んでみる? */
 	for(lba=next_start-4; lba<next_start; lba++){
 		ret = SendReadCD(drive, lba, 1);
 		if(ret!=RET_OK)
@@ -375,7 +375,7 @@ static int AdjustTrackSize(CMDDRIVE *drive, CPDISCINFO *discinfo,
 	track_size = lba-Get4bytes(cpti->trackinfo.track_start);
 #if 0
 	if(track_size != Get4bytes(cpti->trackinfo.track_size)){
-		sprintf(buf, "gbN%d ̃TCY 0x%08lX  0x%08lX ɕύX܂B",
+		sprintf(buf, "トラック%d のサイズは 0x%08lX から 0x%08lX に変更されました。",
 				track_num, Get4bytes(cpti->trackinfo.track_size), track_size);
 		UIDispMessage(buf, UIDMT_INFORMATION);
 	}
@@ -386,11 +386,11 @@ static int AdjustTrackSize(CMDDRIVE *drive, CPDISCINFO *discinfo,
 }
 
 /**
- * CD-TEXT擾
- * @param[in]	drive	ǎ摕u\
- * @param[out]	discinfo  fBXN
- * @retval	RET_OK	I
- * @retval	RET_NG	G[
+ * CD-TEXT情報取得
+ * @param[in]	drive	読取装置構造体
+ * @param[out]	discinfo  ディスク情報
+ * @retval	RET_OK	正常終了
+ * @retval	RET_NG	エラー
  */
 static int GetCDText(CMDDRIVE *drive, CPDISCINFO *discinfo)
 {
@@ -403,7 +403,7 @@ static int GetCDText(CMDDRIVE *drive, CPDISCINFO *discinfo)
 	}
 	len = Get2bytes(drive->data_buf);
 	if(len<=2){	/* header(4bytes) - length field(2bytes) */
-		/* CD-TEXTȂ */
+		/* CD-TEXTなし */
 		return RET_OK;
 	}
 	len -= 2;
@@ -415,44 +415,23 @@ static int GetCDText(CMDDRIVE *drive, CPDISCINFO *discinfo)
 	return RET_OK;
 }
 
-
 /**
- * fBXN擾(ISOC[W)
- * @param[in]	drive	ǎ摕u\
- * @param[out]	discinfo  fBXN
- * @retval	RET_OK	I
- * @retval	RET_NG	G[
+ * @brief 1セッション1トラックのディスク情報を作成する
+ * @param[in] track_size トラックサイズ
+ * @param[out] discinfo ディスク情報
+ * @retval RET_OK 正常終了
+ * @retval RET_MEMERR メモリ確保エラー
  */
-static int GetDiscInformationISO(CMDDRIVE *drive, CPDISCINFO *discinfo)
+static int CreateDummyDiscInformation(DWORD track_size, CPDISCINFO *discinfo)
 {
-	DWORD track_size;
-#ifdef WIN32
-	__int64 file_size;
-#else
-	off_t file_size;
-#endif
-
-	/* t@CTCY擾 */
-#ifdef WIN32
-	file_size = _lseeki64(_fileno(drive->u.image.fp), 0, SEEK_END);
-	_lseeki64(_fileno(drive->u.image.fp), 0, SEEK_SET);
-#else
-	fseeko(drive->u.image.fp, 0, SEEK_END);
-	file_size = ftello(drive->u.image.fp);
-	fseeko(drive->u.image.fp, 0, SEEK_SET);
-#endif
-	track_size = (DWORD)((file_size+2047)/2048);
-		
-	/* fBXNݒ */
+	/* ディスク情報設定 */
 	discinfo->disc_stat = DISCSTAT_COMPLETE;
 	discinfo->last_sess_stat = SESSSTAT_COMPLETE;
-	discinfo->last_addr = (DWORD)(track_size-1);
+	discinfo->last_addr = (DWORD)(track_size > 0 ? track_size-1 : 0);
 	discinfo->sessions = 1;
 	discinfo->tracks = 1;
 	discinfo->trackinfo = (CPTRACKINFO *)MemNew(sizeof(CPTRACKINFO));
 	if(discinfo->trackinfo==NULL){
-		MemFree(discinfo->cdtext);
-		discinfo->cdtext = NULL;
 		return RET_MEMERR;
 	}
 	memset(discinfo->trackinfo, 0, sizeof(CPTRACKINFO));
@@ -464,16 +443,73 @@ static int GetDiscInformationISO(CMDDRIVE *drive, CPDISCINFO *discinfo)
 	discinfo->trackinfo->trackinfo.data_mode = 0x0f;
 	Set4bytes(discinfo->trackinfo->trackinfo.track_start, 0);
 	Set4bytes(discinfo->trackinfo->trackinfo.track_size, track_size);
-
 	return RET_OK;
 }
 
 /**
- * fBXN擾(C[Wt@C)
- * @param[in]	drive	ǎ摕u\
- * @param[out]	discinfo  fBXN
- * @retval	RET_OK	I
- * @retval	RET_NG	G[
+ * @brief ディスク情報取得(mkisofs)
+ * @param[in] drive 読取装置構造体
+ * @param[in] discinfo ディスク情報
+ * @retval RET_OK 正常終了
+ * @retval RET_NG エラー
+ * @retval RET_MEMERR メモリ確保エラー
+ */
+static int GetDiscInformationMkisofs(CMDDRIVE *drive, CPDISCINFO *discinfo)
+{
+	DWORD track_size = 0;
+	UIDispInfo(MSG_READING);
+	if(UICheckAbort()){
+		return RET_ABORT;
+	}
+	track_size = MIFGetBlockCount(&drive->u.mkisofs);
+	if(track_size == 0){
+		char *message = EbStringNewWithFormat(
+			MSG_MKISOFS_ERROR_,
+			MIFGetErrorMessage(&drive->u.mkisofs));
+		UIDispMessage(message, UIDMT_ERROR);
+		EbStringFree(message);
+		return RET_NG;
+	}
+	UIDispInfo("");
+	return CreateDummyDiscInformation(track_size, discinfo);
+}
+
+/**
+ * ディスク情報取得(ISOイメージ)
+ * @param[in]	drive	読取装置構造体
+ * @param[out]	discinfo  ディスク情報
+ * @retval	RET_OK	正常終了
+ * @retval	RET_NG	エラー
+ */
+static int GetDiscInformationISO(CMDDRIVE *drive, CPDISCINFO *discinfo)
+{
+	DWORD track_size;
+#ifdef WIN32
+	__int64 file_size;
+#else
+	off_t file_size;
+#endif
+
+	/* ファイルサイズ取得 */
+#ifdef WIN32
+	file_size = _lseeki64(_fileno(drive->u.image.fp), 0, SEEK_END);
+	_lseeki64(_fileno(drive->u.image.fp), 0, SEEK_SET);
+#else
+	fseeko(drive->u.image.fp, 0, SEEK_END);
+	file_size = ftello(drive->u.image.fp);
+	fseeko(drive->u.image.fp, 0, SEEK_SET);
+#endif
+	track_size = (DWORD)((file_size+2047)/2048);
+		
+	return CreateDummyDiscInformation(track_size, discinfo);
+}
+
+/**
+ * ディスク情報取得(イメージファイル)
+ * @param[in]	drive	読取装置構造体
+ * @param[out]	discinfo  ディスク情報
+ * @retval	RET_OK	正常終了
+ * @retval	RET_NG	エラー
  */
 static int GetDiscInformationImage(CMDDRIVE *drive, CPDISCINFO *discinfo)
 {
@@ -487,11 +523,11 @@ static int GetDiscInformationImage(CMDDRIVE *drive, CPDISCINFO *discinfo)
 }
 
 /**
- * fBXN擾(hCu)
- * @param[in]	drive	ǎ摕u\
- * @param[out]	discinfo  fBXN
- * @retval	RET_OK	I
- * @retval	RET_NG	G[
+ * ディスク情報取得(実ドライブ)
+ * @param[in]	drive	読取装置構造体
+ * @param[out]	discinfo  ディスク情報
+ * @retval	RET_OK	正常終了
+ * @retval	RET_NG	エラー
  */
 static int GetDiscInformationDrive(CMDDRIVE *drive, CPDISCINFO *discinfo)
 {
@@ -526,7 +562,7 @@ static int GetDiscInformationDrive(CMDDRIVE *drive, CPDISCINFO *discinfo)
 
 	if(discinfo->disc_stat == DISCSTAT_EMPTY){
 		UIDispMessage(MSG_SOURCE_IS_BLANK
-					  /*"ʌfBXN̓uNłBʂł܂B"*/,
+					  /*"複写元ディスクはブランクです。複写できません。"*/,
 					  UIDMT_INFORMATION);
 		return RET_ABORT;
 	}	  
@@ -549,7 +585,7 @@ static int GetDiscInformationDrive(CMDDRIVE *drive, CPDISCINFO *discinfo)
 		}
 	}
 
-	/* gbNƂɏ擾 */
+	/* トラックごとに情報を取得 */
 	UIMeter1Initialize(MSG_READING);
 	if(drive->type==CMDDRVTYPE_NET){
 		NAUIMeter1Initialize(&drive->u.net, MSG_READING);
@@ -592,11 +628,11 @@ static int GetDiscInformationDrive(CMDDRIVE *drive, CPDISCINFO *discinfo)
 			return RET_ABORT;
 		}
 		cpti = &discinfo->trackinfo[track_num-1];
-		/* ZbVTAOL^ǂ𒲂ׂ */
+		/* セッションがTAO記録かどうかを調べる */
 		sess_num = (WORD)cpti->trackinfo.session_number_msb<<8 |
 			cpti->trackinfo.session_number_lsb;
 		if(sess_num != last_sess_num){
-			/* TAOSAOf */
+			/* TAOかSAOか判断 */
 			ret = JudgeTAO(drive, discinfo, sess_num, &tao);
 			if(ret!=RET_OK){
 				MemFree(discinfo->cdtext);
@@ -605,7 +641,7 @@ static int GetDiscInformationDrive(CMDDRIVE *drive, CPDISCINFO *discinfo)
 				discinfo->trackinfo = NULL;
 				return ret;
 			}
-			/* [hAEgJnAhX擾 */
+			/* リードアウト開始アドレスを取得 */
 			ret = GetLeadOutStart(drive, discinfo, sess_num, &lout_start);
 			if(ret!=RET_OK){
 				MemFree(discinfo->cdtext);
@@ -617,7 +653,7 @@ static int GetDiscInformationDrive(CMDDRIVE *drive, CPDISCINFO *discinfo)
 			last_sess_num = sess_num;
 		}
 		cpti->tao = tao;
-		/* ZbV̍ŏIgbNTCY */
+		/* セッションの最終トラックサイズ調整 */
 		ret = AdjustTrackSize(drive, discinfo, track_num, lout_start);
 		if(ret!=RET_OK){
 			MemFree(discinfo->cdtext);
@@ -626,7 +662,7 @@ static int GetDiscInformationDrive(CMDDRIVE *drive, CPDISCINFO *discinfo)
 			discinfo->trackinfo = NULL;
 			return ret;
 		}
-		/* fBXNŏIAhXXV */
+		/* ディスク最終アドレス更新 */
 		if(cpti->trackinfo.nwa_valid){
 			if(Get4bytes(cpti->trackinfo.next_writable_addr) > Get4bytes(cpti->trackinfo.track_start))
 				last_addr = Get4bytes(cpti->trackinfo.next_writable_addr);
@@ -639,9 +675,9 @@ static int GetDiscInformationDrive(CMDDRIVE *drive, CPDISCINFO *discinfo)
 	discinfo->last_addr = last_addr;
   
 	if(DT_DVD_FAMILY(drive->disc_type) && discinfo->tracks>1){
-		/* DVDDAOł͕gbNL^łȂ */
+		/* DVDのDAOでは複数トラック記録できない */
 		if(GetOption()->dao){
-			/* gbN݂̂ DAO L^ł܂B\nTAO ŋL^𑱍s܂?" */
+			/* トラックが複数存在するので DAO 記録できません。\nTAO で記録を続行しますか?" */
 			ret = UIDispMessage(MSG_CANT_DAO,
 								UIDMT_QUESTION);
 			if(ret!=UIDMRET_OK){
@@ -655,20 +691,20 @@ static int GetDiscInformationDrive(CMDDRIVE *drive, CPDISCINFO *discinfo)
 		}
 	}
 
-	UIMeter1Initialize(MSG_TOTAL /*"S"*/);
+	UIMeter1Initialize(MSG_TOTAL /*"全体"*/);
 	if(drive->type==CMDDRVTYPE_NET){
-		NAUIMeter1Initialize(&drive->u.net, MSG_TOTAL /*"S"*/);
+		NAUIMeter1Initialize(&drive->u.net, MSG_TOTAL /*"全体"*/);
 	}
 
 	return RET_OK;
 }
 
 /**
- * fBXN擾
- * @param[in]	drive	ǎ摕u\
- * @param[out]	discinfo  fBXN
- * @retval	RET_OK	I
- * @retval	RET_NG	G[
+ * ディスク情報取得
+ * @param[in]	drive	読取装置構造体
+ * @param[out]	discinfo  ディスク情報
+ * @retval	RET_OK	正常終了
+ * @retval	RET_NG	エラー
  */
 int GetDiscInformation(CMDDRIVE *drive, CPDISCINFO *discinfo)
 {
@@ -676,15 +712,22 @@ int GetDiscInformation(CMDDRIVE *drive, CPDISCINFO *discinfo)
 
 	memset(discinfo, 0, sizeof(CPDISCINFO));
 	if(!REALDRIVE(drive)){
-		if(drive->type == CMDDRVTYPE_ISO){
-			/* ISOC[Wt@C̏ꍇ */
+		if(drive->type == CMDDRVTYPE_MKISOFS){
+			/* フォルダからのISOイメージ(mkisofs)の場合 */
+			ret = GetDiscInformationMkisofs(drive, discinfo);
+			if(ret != RET_OK){
+				return ret;
+			}
+		}
+		else if(drive->type == CMDDRVTYPE_ISO){
+			/* ISOイメージファイルの場合 */
 			ret = GetDiscInformationISO(drive, discinfo);
 			if(ret != RET_OK){
 				return ret;
 			}
 		}
-		else{
-			/* C[Wt@CfBXN𓾂 */
+		else if(drive->type == CMDDRVTYPE_IMAGE){
+			/* イメージファイル(emg)からディスク情報を得る */
 			ret = GetDiscInformationImage(drive, discinfo);
 			if(ret != RET_OK){
 				return ret;
@@ -692,7 +735,7 @@ int GetDiscInformation(CMDDRIVE *drive, CPDISCINFO *discinfo)
 		}
 	}
 	else{
-		/* hCu擾 */
+		/* 実ドライブから情報取得 */
 		ret = GetDiscInformationDrive(drive, discinfo);
 		if(ret != RET_OK){
 			return ret;
