@@ -1,9 +1,9 @@
 /**
  * @file discinfo.h
- * @brief fBXN擾֘A
+ * @brief ディスク情報取得関連
  * @author BananaJinn
- * @version $Id: discinfo.h,v 1.3 2007/01/21 15:43:48 bananajinn Exp $
- * ~Օʉ
+ * @version $Id: discinfo.h,v 1.4 2010/11/05 17:24:03 bananajinn Exp $
+ * 円盤複写屋
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
 #ifndef __DISCINFO_H__
@@ -11,9 +11,9 @@
 
 typedef struct {
   struct _TRACKINFO trackinfo;
-  BYTE mode2;			/* MODE2Ȃ1AȊO0 */
+  BYTE mode2;			/* MODE2なら1、それ以外は0 */
   BYTE isrc[12+1];
-  BOOL tao;			/* TAOŋL^Ă邩ǂ */
+  BOOL tao;			/* TAOで記録されているかどうか */
   WORD pause_len;		/* Audio Pause Length */
 } CPTRACKINFO;
 
@@ -29,8 +29,8 @@ typedef struct {
   WORD tracks;
   BYTE *cdtext;
   DWORD cdtext_size;
-  DWORD outside_offset;		/* ISOOL^̃ItZbg */
-  CPTRACKINFO *trackinfo;	/* <= KŌ */
+  DWORD outside_offset;		/* ISO外側記録のオフセット */
+  CPTRACKINFO *trackinfo;	/* <= 必ず最後 */
 } CPDISCINFO;
 
 
