@@ -1,9 +1,9 @@
 /**
  * @file emg.c
- * @brief ~ՕʉC[Wǂݏ
+ * @brief 円盤複写屋イメージ読み書き
  * @author BananaJinn
- * @version $Id: emg.c,v 1.4 2007/01/30 15:49:27 bananajinn Exp $
- * ~Օʉ
+ * @version $Id: emg.c,v 1.5 2010/11/05 17:24:03 bananajinn Exp $
+ * 円盤複写屋
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
 #include <stdio.h>
@@ -22,30 +22,30 @@
 #include "emg.h"
 
 /**
- * @brief ~ՕʉC[W̃gbN
+ * @brief 円盤複写屋イメージのトラック情報
  */
 typedef struct {
   BYTE mark[4];			/**< "ETRK" */
-  struct _TRACKINFO trackinfo;	/**< hCuǂݏogbN */
-  BYTE mode2;			/**< mode2ǂ */
+  struct _TRACKINFO trackinfo;	/**< ドライブから読み出したトラック情報 */
+  BYTE mode2;			/**< mode2かどうか */
   BYTE isrc[12+1];		/**< ISRC */
-  BYTE tao;			/**< TAOǂ */
+  BYTE tao;			/**< TAOかどうか */
   BYTE pause_len[2];		/**< AUDIO PAUSE LENGTH */
 } EMG_TRACKINFO;
 
 /**
- * @brief ~ՕʉC[W̃fBXN
+ * @brief 円盤複写屋イメージのディスク情報
  */
 typedef struct {
   BYTE mark[4];			/**< "EDSC" */
-  BYTE disc_type;		/**< fBXN */
-  BYTE disc_stat;		/**< fBXNXe[^X */
-  BYTE last_sess_stat;		/**< ŏIZbVXe[^X */
-  BYTE mcn[13+1];		/**< fBAJ^Oԍ */
-  BYTE last_addr[4];		/**< ŏIAhX(LBA) */
-  BYTE sessions[2];		/**< ZbV */
-  BYTE tracks[2];		/**< gbN */
-  BYTE cdtext_size[4];		/**< CD-TEXTTCY(oCg) */
+  BYTE disc_type;		/**< ディスク種別 */
+  BYTE disc_stat;		/**< ディスクステータス */
+  BYTE last_sess_stat;		/**< 最終セッションステータス */
+  BYTE mcn[13+1];		/**< メディアカタログ番号 */
+  BYTE last_addr[4];		/**< 最終アドレス(LBA) */
+  BYTE sessions[2];		/**< セッション数 */
+  BYTE tracks[2];		/**< トラック数 */
+  BYTE cdtext_size[4];		/**< CD-TEXTサイズ(バイト数) */
 } EMG_DISCINFO;
 
 #define EMGMARK_SIZE 4
@@ -56,11 +56,11 @@ typedef struct {
 #define EMGMARK_DATA ((BYTE *)"EDTA")
 
 /**
- * @brief ~ՕʉC[W`ŃfBXNt@Cɏ
- * @param[in] image C[Wt@C
- * @param[in] discinfo ރfBXN
- * @retval RET_OK	I
- * @retval RET_NG	G[
+ * @brief 円盤複写屋イメージ形式でディスク情報をファイルに書き込み
+ * @param[in] image イメージファイル
+ * @param[in] discinfo 書き込むディスク情報
+ * @retval RET_OK	正常終了
+ * @retval RET_NG	エラー
  */
 int EmgWriteDiscInformation(IMAGEFILE *image, CPDISCINFO *discinfo)
 {
@@ -134,11 +134,11 @@ int EmgWriteDiscInformation(IMAGEFILE *image, CPDISCINFO *discinfo)
 
 
 /**
- * @brief C[Wt@C4oCgǂݎA}[NmF
- * @param[in] image C[Wt@C
- * @param[in] mark }[N4oCg
- * @retval RET_OK	mFOK
- * @retval RET_NG	mFNG
+ * @brief イメージファイルから4バイト読み取り、マークを確認する
+ * @param[in] image イメージファイル
+ * @param[in] mark マーク4バイト
+ * @retval RET_OK	確認OK
+ * @retval RET_NG	確認NG
  */
 static int EmgCheckMark(IMAGEFILE *image, BYTE *mark)
 {
@@ -151,7 +151,7 @@ static int EmgCheckMark(IMAGEFILE *image, BYTE *mark)
   }
   if(memcmp(buf, mark, sizeof(buf))){
     UIDispMessage(MSG_INVALID_IMAGE_FILE
-		  /*"sȃC[Wt@CłB"*/, UIDMT_ERROR);
+		  /*"不正なイメージファイルです。"*/, UIDMT_ERROR);
     return RET_NG;
   }
   return RET_OK;
@@ -159,11 +159,11 @@ static int EmgCheckMark(IMAGEFILE *image, BYTE *mark)
 
 
 /**
- * @brief ~ՕʉC[W`ŃfBXNt@Cǂݍ
- * @param[in] image C[Wt@C
- * @param[out] discinfo ރfBXN
- * @retval RET_OK	I
- * @retval RET_NG	G[
+ * @brief 円盤複写屋イメージ形式でディスク情報をファイルから読み込み
+ * @param[in] image イメージファイル
+ * @param[out] discinfo 書き込むディスク情報
+ * @retval RET_OK	正常終了
+ * @retval RET_NG	エラー
  */
 int EmgReadDiscInformation(IMAGEFILE *image, CPDISCINFO *discinfo)
 {
@@ -184,7 +184,7 @@ int EmgReadDiscInformation(IMAGEFILE *image, CPDISCINFO *discinfo)
   }
   if(Get4bytes(version) != EMGFILE_VERSION){
     UIDispMessage(MSG_INVALID_IMAGE_FILE
-		  /*"sȃC[Wt@CłB"*/, UIDMT_ERROR);
+		  /*"不正なイメージファイルです。"*/, UIDMT_ERROR);
     return RET_NG;
   }
   
@@ -194,7 +194,7 @@ int EmgReadDiscInformation(IMAGEFILE *image, CPDISCINFO *discinfo)
   }
   if(memcmp(emg_disc->mark, EMGMARK_DISCINFO, EMGMARK_SIZE)){
     UIDispMessage(MSG_INVALID_IMAGE_FILE
-		  /*"sȃC[Wt@CłB"*/, UIDMT_ERROR);
+		  /*"不正なイメージファイルです。"*/, UIDMT_ERROR);
     return RET_NG;
   }
   memset(discinfo, 0, sizeof(CPDISCINFO));
@@ -249,7 +249,7 @@ int EmgReadDiscInformation(IMAGEFILE *image, CPDISCINFO *discinfo)
       MemFree(discinfo->cdtext);
       discinfo->cdtext = NULL;
       UIDispMessage(MSG_INVALID_IMAGE_FILE
-		    /*"sȃC[Wt@CłB"*/, UIDMT_ERROR);
+		    /*"不正なイメージファイルです。"*/, UIDMT_ERROR);
       return RET_NG;
     }
     memcpy(&trackinfo->trackinfo, &emg_track->trackinfo,
