@@ -1,9 +1,9 @@
 /**
  * @file netaccess.c
- * @brief lbg[NANZX
+ * @brief ネットワークアクセス
  * @author BananaJinn
- * @version $Id: netaccess.c,v 1.21 2007/10/02 15:10:52 bananajinn Exp $
- * ~Օʉ
+ * @version $Id: netaccess.c,v 1.23 2010/11/01 14:34:11 bananajinn Exp $
+ * 円盤複写屋
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
 #include <stdio.h>
@@ -34,6 +34,7 @@
 #include "netaccess.h"
 #include "ui.h"
 #include "text.h"
+#include "ebstring.h"
 
 static void SetErrorCode(SOCKCB *scb)
 {
@@ -45,15 +46,15 @@ static void SetErrorCode(SOCKCB *scb)
 }
 
 /**
- * @brief	\Pbg҂
- * @param[out]	read_fds	ǂݍݗp
- * @param[out]	write_fds	ݗp
- * @param[out]	except_fds	Op
- * @param[in]	sd			\PbgfXNv^
- * @param[in]	timeout		^CAEg(~b)
- * @retval	RET_OK	\Pbgo͗L
- * @retval	RET_TIMEOUT	^CAEg
- * @retval	RET_NG	G[
+ * @brief	ソケット待ち
+ * @param[out]	read_fds	読み込み用
+ * @param[out]	write_fds	書き込み用
+ * @param[out]	except_fds	例外用
+ * @param[in]	sd			ソケットデスクリプタ
+ * @param[in]	timeout		タイムアウト(ミリ秒)
+ * @retval	RET_OK	ソケット入出力有り
+ * @retval	RET_TIMEOUT	タイムアウト
+ * @retval	RET_NG	エラー
  */
 static int WaitFDS(fd_set *read_fds, fd_set *write_fds, fd_set *except_fds,
 				   SOCKET sd, DWORD timeout)
@@ -101,10 +102,10 @@ static int WaitFDS(fd_set *read_fds, fd_set *write_fds, fd_set *except_fds,
 
   
 /**
- * @brief \PbgubN
- * @param[out] scb \PbgubN
- * @retval RET_OK I
- * @retval RET_SOCKET \PbgG[
+ * @brief ソケット制御ブロック初期化
+ * @param[out] scb 初期化するソケット制御ブロック
+ * @retval RET_OK 正常終了
+ * @retval RET_SOCKET ソケットエラー
  */
 int InitializeSOCKCB(SOCKCB *scb)
 {
@@ -125,9 +126,9 @@ int InitializeSOCKCB(SOCKCB *scb)
 }
 
 /**
- * @brief \PbgubN
- * @param[in] scb \PbgubN
- * @retval RET_OK I
+ * @brief ソケット制御ブロック解放
+ * @param[in] scb 解放するソケット制御ブロック
+ * @retval RET_OK 正常終了
  */
 int FreeSOCKCB(SOCKCB *scb)
 {
@@ -152,10 +153,10 @@ int FreeSOCKCB(SOCKCB *scb)
 
 
 /**
- * @brief T[o\Pbg쐬
- * @param[in,out] scb \PbgubN
- * @retval RET_OK I
- * @retval RET_SOCKET \PbgG[
+ * @brief サーバソケット作成
+ * @param[in,out] scb ソケット制御ブロック
+ * @retval RET_OK 正常終了
+ * @retval RET_SOCKET ソケットエラー
  */
 int NACreateServer(SOCKCB *scb)
 {
@@ -196,13 +197,13 @@ int NACreateServer(SOCKCB *scb)
 }
 
 /**
- * @brief \Pbgڑv҂
- * @param[in,out] scb \PbgubN
- * @param[in] timeout ^CAEg(~b)
- * @retval RET_OK I
- * @retval RET_TIMEOUT ^CAEg
- * @retval RET_SOCKET \PbgG[
- * @retval RET_NG ̑̃G[
+ * @brief ソケット接続要求待ち
+ * @param[in,out] scb ソケット制御ブロック
+ * @param[in] timeout タイムアウト時間(ミリ秒)
+ * @retval RET_OK 正常終了
+ * @retval RET_TIMEOUT タイムアウト発生
+ * @retval RET_SOCKET ソケットエラー
+ * @retval RET_NG その他のエラー
  */
 int NAWaitConnect(SOCKCB *scb, DWORD timeout)
 {
@@ -254,11 +255,11 @@ int NAWaitConnect(SOCKCB *scb, DWORD timeout)
 
 
 /**
- * @brief \Pbgڑ
- * @param[in,out] scb \PbgubN
- * @retval RET_OK I
- * @retval RET_SOCKET \PbgG[
- * @retval RET_NG ̑̃G[
+ * @brief ソケット接続
+ * @param[in,out] scb ソケット制御ブロック
+ * @retval RET_OK 正常終了
+ * @retval RET_SOCKET ソケットエラー
+ * @retval RET_NG その他のエラー
  */
 int NAConnect(SOCKCB *scb)
 {
@@ -315,10 +316,10 @@ int NAConnect(SOCKCB *scb)
 
 
 /**
- * @brief \PbgN[Y
- * @param[in,out] scb \PbgubN
- * @retval RET_OK I
- * @retval RET_SOCKET \PbgG[
+ * @brief ソケットクローズ
+ * @param[in,out] scb ソケット制御ブロック
+ * @retval RET_OK 正常終了
+ * @retval RET_SOCKET ソケットエラー
  */
 int NAClose(SOCKCB *scb)
 {
@@ -372,18 +373,18 @@ int NAClose(SOCKCB *scb)
 
 
 /**
- * @brief \PbgM
- * @param[in,out] scb \PbgubN
- * @param[in] buffer Mf[^obt@
- * @param[in] length Mf[^oCg
- * @param[in] tmieout ^CAEg(~b)
- * @param[in] check_readfd READpfdĎ邩ǂ
- * @retval RET_OK I
- * @retval RET_READFD check_readfdw莞READpfdǂݎ\ƂȂ
- * @retval RET_SOCKET \PbgG[
- * @retval RET_ABORT ڑfO
- * @retval RET_TIMEOUT ^CAEg
- * @retval RET_NG ̑̃G[
+ * @brief ソケット送信
+ * @param[in,out] scb ソケット制御ブロック
+ * @param[in] buffer 送信データバッファ
+ * @param[in] length 送信データバイト数
+ * @param[in] tmieout タイムアウト(ミリ秒)
+ * @param[in] check_readfd READ用fdを監視するかどうか
+ * @retval RET_OK 正常終了
+ * @retval RET_READFD check_readfd指定時にREAD用のfdが読み取り可能となった
+ * @retval RET_SOCKET ソケットエラー
+ * @retval RET_ABORT 接続断念
+ * @retval RET_TIMEOUT タイムアウト発生
+ * @retval RET_NG その他のエラー
  */
 int NASend(SOCKCB *scb, const void *buffer, int length, DWORD timeout,
 		   BOOL check_readfd)
@@ -437,15 +438,15 @@ int NASend(SOCKCB *scb, const void *buffer, int length, DWORD timeout,
 }
 
 /**
- * @brief	\Pbgf[^M
- * @param[in,out]	scb		\PbgubN
- * @param[out]	buffer	Mf[^i[̈(NULLwŃf[^̂Ă)
- * @param[in]	length	Mf[^
- * @param[in]	timeout	^CAEg(~b)
- * @retval	RET_OK	I
- * @retval	RET_TIMEOUT	^CAEg
- * @retval	RET_ABORT	f(葤ؒfꂽ)
- * @retval	RET_SOCKET	\PbgG[
+ * @brief	ソケットからデータ受信
+ * @param[in,out]	scb		ソケット制御ブロック
+ * @param[out]	buffer	受信データ格納領域(NULL指定でデータを捨てる)
+ * @param[in]	length	受信データ長
+ * @param[in]	timeout	タイムアウト(ミリ秒)
+ * @retval	RET_OK	正常終了
+ * @retval	RET_TIMEOUT	タイムアウト
+ * @retval	RET_ABORT	中断(相手側より切断された)
+ * @retval	RET_SOCKET	ソケットエラー
  */
 int NAReceive(SOCKCB *scb, void *buffer, int length, DWORD timeout)
 {
@@ -501,19 +502,19 @@ int NAReceive(SOCKCB *scb, void *buffer, int length, DWORD timeout)
 
 
 /**
- * @brief R}hM
- * @param[in,out] scb \PbgubN
- * @param[out] buf f[^i[obt@
- * @param[in] buflen obt@TCY(oCg)
- * @param[out] sensedata ZXf[^i[obt@
- * @param[in] senselen ZXf[^i[obt@TCY(oCg)
- * @param[in] reqflag vtO(REQ_NODATA/REQ_DATAIN/REQ_DATAOUT)
- * @param[out] cmd_header R}hwb_[
- * @retval RET_OK I
- * @retval RET_ABORT f
- * @retval RET_TIMEOUT ^CAEg
- * @retval RET_SOCKET \PbgG[
- * @retval RET_NG ̑̃G[
+ * @brief コマンド応答を受信
+ * @param[in,out] scb ソケット制御ブロック
+ * @param[out] buf 応答データ格納バッファ
+ * @param[in] buflen バッファサイズ(バイト数)
+ * @param[out] sensedata センスデータ格納バッファ
+ * @param[in] senselen センスデータ格納バッファサイズ(バイト数)
+ * @param[in] reqflag 要求フラグ(REQ_NODATA/REQ_DATAIN/REQ_DATAOUT)
+ * @param[out] cmd_header コマンドヘッダー
+ * @retval RET_OK 正常終了
+ * @retval RET_ABORT 中断
+ * @retval RET_TIMEOUT タイムアウト発生
+ * @retval RET_SOCKET ソケットエラー
+ * @retval RET_NG その他のエラー
  */
 static int ReceiveCmdResponse(SOCKCB *scb, void *buf, DWORD buflen,
 							  BYTE *sensedata, DWORD senselen,
@@ -529,7 +530,7 @@ static int ReceiveCmdResponse(SOCKCB *scb, void *buf, DWORD buflen,
 		cmd_header = &recv_header;
 	}
   
-	/* ʕ(f[^ƃf[^^Cv)M */
+	/* 共通部(データ長とデータタイプ)を受信する */
 	ret = NAReceive(scb, (char *)netdata_common, 8, NETTIMEOUT);
 	if(ret != RET_OK){
 		return ret;
@@ -565,19 +566,19 @@ static int ReceiveCmdResponse(SOCKCB *scb, void *buf, DWORD buflen,
 
 
 /**
- * @brief R}hf[^M
- * @param[in,out] scb \PbgubN
- * @param[in] cdb R}h(12oCg)
- * @param[in,out] buf MR}hɕtf[^ / Mf[^
- * @param[in] buflen obt@TCY(oCg)
- * @param[out] sensedata ZXf[^i[obt@
- * @param[in] senselen ZXf[^i[obt@TCY(oCg)
- * @param[in] reqflag vtO(REQ_NODATA/REQ_DATAIN/REQ_DATAOUT)
- * @retval RET_OK I
- * @retval RET_ABORT f
- * @retval RET_TIMEOUT ^CAEg
- * @retval RET_SOCKET \PbgG[
- * @retval RET_NG ̑̃G[
+ * @brief コマンドデータ送信
+ * @param[in,out] scb ソケット制御ブロック
+ * @param[in] cdb コマンド列(12バイト)
+ * @param[in,out] buf 送信コマンドに付随するデータ / 受信データ
+ * @param[in] buflen バッファサイズ(バイト数)
+ * @param[out] sensedata センスデータ格納バッファ
+ * @param[in] senselen センスデータ格納バッファサイズ(バイト数)
+ * @param[in] reqflag 要求フラグ(REQ_NODATA/REQ_DATAIN/REQ_DATAOUT)
+ * @retval RET_OK 正常終了
+ * @retval RET_ABORT 中断
+ * @retval RET_TIMEOUT タイムアウト発生
+ * @retval RET_SOCKET ソケットエラー
+ * @retval RET_NG その他のエラー
  */
 int SendNetCmd(SOCKCB *scb, BYTE *cdb, void *buf, DWORD buflen,
 			   BYTE *sensedata, DWORD senselen, int reqflag)
@@ -597,13 +598,13 @@ int SendNetCmd(SOCKCB *scb, BYTE *cdb, void *buf, DWORD buflen,
 	memcpy(header.cdb, cdb, 12);
 	Set4bytes(header.data_length, buflen);
 
-	/* ʕ(f[^ƃf[^^Cv)𑗂 */
+	/* 共通部(データ長とデータタイプ)を送る */
 	ret = NASend(scb, netdata_common, 8, NETTIMEOUT, FALSE);
 	if(ret != RET_OK){
 		return ret;
 	}
 
-	/* ʕ𑗂 */
+	/* 個別部を送る */
 	ret = NASend(scb, &header, sizeof(NETCMDHEADER), NETTIMEOUT, FALSE);
 	if(ret != RET_OK){
 		return ret;
@@ -627,21 +628,21 @@ int SendNetCmd(SOCKCB *scb, BYTE *cdb, void *buf, DWORD buflen,
 }
 
 /**
- * @brief NetworkoRLONGREAD𑗐MB܂́ALONGREADʂMB
- *        total_blocks0̏ꍇɌʎMsAȊȌꍇ́AMsB
- * @param[in,out] scb \PbgubN
- * @param[in] cdb R}h(12oCg)
- * @param[out] buf Mobt@
- * @param[in] buflen Mobt@TCY(oCg)
- * @param[out] sensedata ZXf[^i[obt@
- * @param[in] senselen ZXf[^i[obt@TCY(oCg)
- * @param[in] reqflag vtO(REQ_NODATA/REQ_DATAIN/REQ_DATAOUT)
- * @param[in] total_blocks READubN
- * @retval RET_OK I
- * @retval RET_ABORT f
- * @retval RET_TIMEOUT ^CAEg
- * @retval RET_SOCKET \PbgG[
- * @retval RET_NG ̑̃G[
+ * @brief Network経由でLONGREADを送信する。または、LONGREAD結果を受信する。
+ *        total_blocksが0の場合に結果受信を行い、それ以外の場合は、送信を行う。
+ * @param[in,out] scb ソケット制御ブロック
+ * @param[in] cdb コマンド列(12バイト)
+ * @param[out] buf 受信バッファ
+ * @param[in] buflen 受信バッファサイズ(バイト数)
+ * @param[out] sensedata センスデータ格納バッファ
+ * @param[in] senselen センスデータ格納バッファサイズ(バイト数)
+ * @param[in] reqflag 要求フラグ(REQ_NODATA/REQ_DATAIN/REQ_DATAOUT)
+ * @param[in] total_blocks READブロック数
+ * @retval RET_OK 正常終了
+ * @retval RET_ABORT 中断
+ * @retval RET_TIMEOUT タイムアウト発生
+ * @retval RET_SOCKET ソケットエラー
+ * @retval RET_NG その他のエラー
  */
 int SendNetCmdLongRead(SOCKCB *scb, BYTE *cdb, void *buf, DWORD buflen,
 					   BYTE *sensedata, DWORD senselen,
@@ -654,7 +655,7 @@ int SendNetCmdLongRead(SOCKCB *scb, BYTE *cdb, void *buf, DWORD buflen,
 	DWORD length;
 
 	if(total_blocks == 0){
-		/* LONGREADʎM */
+		/* LONGREAD結果受信 */
 		ret = ReceiveCmdResponse(scb, buf, buflen, sensedata, senselen, reqflag,
 								 &recv_header);
 		if(ret != RET_OK){
@@ -662,12 +663,12 @@ int SendNetCmdLongRead(SOCKCB *scb, BYTE *cdb, void *buf, DWORD buflen,
 		}
 	
 		if(memcmp(recv_header.cdb, cdb, 12)){
-			/* R}h */
+			/* コマンド相違 */
 			return RET_NG;
 		}
 	}
 	else{
-		/* LONGREADM */
+		/* LONGREAD送信 */
 		length = sizeof(NETCMDHEADER);
 		if(reqflag==REQ_DATAOUT){
 			length += buflen;
@@ -678,13 +679,13 @@ int SendNetCmdLongRead(SOCKCB *scb, BYTE *cdb, void *buf, DWORD buflen,
 		memcpy(header.cdb, cdb, 12);
 		Set4bytes(header.data_length, buflen);
 
-		/* ʕ(f[^ƃf[^^Cv)𑗂 */
+		/* 共通部(データ長とデータタイプ)を送る */
 		ret = NASend(scb, (char *)netdata_common, 8, NETTIMEOUT, FALSE);
 		if(ret != RET_OK){
 			return ret;
 		}
 
-		/* ʕ𑗂 */
+		/* 個別部を送る */
 		ret = NASend(scb, (char *)&header, sizeof(NETCMDHEADER), NETTIMEOUT,
 					 FALSE);
 		if(ret != RET_OK){
@@ -703,11 +704,11 @@ int SendNetCmdLongRead(SOCKCB *scb, BYTE *cdb, void *buf, DWORD buflen,
 
 #if defined(linux) || defined(__MINGW32__)
 /**
- * @brief R[hϊ
- * @param[in] iconv_desc iconvfBXNv^
- * @param[in] in_string ϊ
- * @return ϊʂ̕BG[ꍇ NULL ԂB
- * @note ϊʕ͎gp MemFree() KvB
+ * @brief 文字コード変換
+ * @param[in] iconv_desc iconvディスクリプタ
+ * @param[in] in_string 変換文字列
+ * @return 変換結果の文字列。エラーが発生した場合は NULL を返す。
+ * @note 変換結果文字列は使用後 MemFree() が必要。
  */
 char *ConvertCharcode(iconv_t iconv_desc, const char *in_string)
 {
@@ -737,11 +738,11 @@ char *ConvertCharcode(iconv_t iconv_desc, const char *in_string)
 			continue;
 		}
 		if(errno != E2BIG){
-			/* ϊs */
+			/* 変換失敗 */
 			MemFree(out_string);
 			return NULL;
 		}
-		/* ̈s */
+		/* 領域不足 */
 		out_offset = (int)(outbufp-out_string);
 		bufsize += 64;
 		outbytes += 64;
@@ -759,19 +760,19 @@ char *ConvertCharcode(iconv_t iconv_desc, const char *in_string)
 
 
 /**
- * @brief \f[^M
- * @param[in,out] scb \PbgubN
- * @param[in] area \̈<br>
- *   0:ʉbZ[W<br>
- *   1:vOXo[1<br>
- *   2:vOXo[2
- * @param[in] percent p[Ze[W
- * @param[in] message \bZ[W
- * @retval RET_OK I
- * @retval RET_SOCKET \PbgG[
- * @retval RET_ABORT f
- * @retval RET_TIMEOUT ^CAEg
- * @retval RET_NG ̑̃G[
+ * @brief 表示データ送信
+ * @param[in,out] scb ソケット制御ブロック
+ * @param[in] area 表示領域<br>
+ *   0:画面下メッセージ<br>
+ *   1:プログレスバー1<br>
+ *   2:プログレスバー2
+ * @param[in] percent パーセンテージ
+ * @param[in] message 表示メッセージ
+ * @retval RET_OK 正常終了
+ * @retval RET_SOCKET ソケットエラー
+ * @retval RET_ABORT 中断
+ * @retval RET_TIMEOUT タイムアウト発生
+ * @retval RET_NG その他のエラー
  */
 int NASendDispCmd(SOCKCB *scb, BYTE area, BYTE percent, const char *message)
 {
@@ -841,13 +842,13 @@ int NASendDispCmd(SOCKCB *scb, BYTE area, BYTE percent, const char *message)
 
 
 /**
- * @brief f𑗐M
- * @param[in,out] scb \PbgubN
- * @retval RET_OK I
- * @retval RET_SOCKET \PbgG[
- * @retval RET_ABORT f
- * @retval RET_TIMEOUT ^CAEg
- * @retval RET_NG ̑̃G[
+ * @brief 中断を送信
+ * @param[in,out] scb ソケット制御ブロック
+ * @retval RET_OK 正常終了
+ * @retval RET_SOCKET ソケットエラー
+ * @retval RET_ABORT 中断
+ * @retval RET_TIMEOUT タイムアウト発生
+ * @retval RET_NG その他のエラー
  */
 int NASendAbort(SOCKCB *scb)
 {
@@ -864,13 +865,13 @@ int NASendAbort(SOCKCB *scb)
 }
 
 /**
- * @brief 𑗐M
- * @param[in,out] scb \PbgubN
- * @retval RET_OK I
- * @retval RET_SOCKET \PbgG[
- * @retval RET_ABORT f
- * @retval RET_TIMEOUT ^CAEg
- * @retval RET_NG ̑̃G[
+ * @brief 完了を送信
+ * @param[in,out] scb ソケット制御ブロック
+ * @retval RET_OK 正常終了
+ * @retval RET_SOCKET ソケットエラー
+ * @retval RET_ABORT 中断
+ * @retval RET_TIMEOUT タイムアウト発生
+ * @retval RET_NG その他のエラー
  */
 int NASendComplete(SOCKCB *scb)
 {
@@ -889,14 +890,14 @@ int NASendComplete(SOCKCB *scb)
 
 
 /**
- * @brief \f[^𑗐M
- * @param[in,out] scb \PbgubN
- * @param[in] message \bZ[W
- * @retval RET_OK I
- * @retval RET_SOCKET \PbgG[
- * @retval RET_ABORT f
- * @retval RET_TIMEOUT ^CAEg
- * @retval RET_NG ̑̃G[
+ * @brief 情報表示データを送信
+ * @param[in,out] scb ソケット制御ブロック
+ * @param[in] message 表示メッセージ
+ * @retval RET_OK 正常終了
+ * @retval RET_SOCKET ソケットエラー
+ * @retval RET_ABORT 中断
+ * @retval RET_TIMEOUT タイムアウト発生
+ * @retval RET_NG その他のエラー
  */
 int NAUIDispInfo(SOCKCB *scb, const char *message)
 {
@@ -904,14 +905,14 @@ int NAUIDispInfo(SOCKCB *scb, const char *message)
 }
 
 /**
- * @brief vOXo[1̏𑗐M
- * @param[in,out] scb \PbgubN
- * @param[in] message \bZ[W
- * @retval RET_OK I
- * @retval RET_SOCKET \PbgG[
- * @retval RET_ABORT f
- * @retval RET_TIMEOUT ^CAEg
- * @retval RET_NG ̑̃G[
+ * @brief プログレスバー1の初期化を送信
+ * @param[in,out] scb ソケット制御ブロック
+ * @param[in] message 表示メッセージ
+ * @retval RET_OK 正常終了
+ * @retval RET_SOCKET ソケットエラー
+ * @retval RET_ABORT 中断
+ * @retval RET_TIMEOUT タイムアウト発生
+ * @retval RET_NG その他のエラー
  */
 int NAUIMeter1Initialize(SOCKCB *scb, const char *message)
 {
@@ -919,14 +920,14 @@ int NAUIMeter1Initialize(SOCKCB *scb, const char *message)
 }
 
 /**
- * @brief vOXo[2̏𑗐M
- * @param[in,out] scb \PbgubN
- * @param[in] message \bZ[W
- * @retval RET_OK I
- * @retval RET_SOCKET \PbgG[
- * @retval RET_ABORT f
- * @retval RET_TIMEOUT ^CAEg
- * @retval RET_NG ̑̃G[
+ * @brief プログレスバー2の初期化を送信
+ * @param[in,out] scb ソケット制御ブロック
+ * @param[in] message 表示メッセージ
+ * @retval RET_OK 正常終了
+ * @retval RET_SOCKET ソケットエラー
+ * @retval RET_ABORT 中断
+ * @retval RET_TIMEOUT タイムアウト発生
+ * @retval RET_NG その他のエラー
  */
 int NAUIMeter2Initialize(SOCKCB *scb, const char *message)
 {
@@ -934,14 +935,14 @@ int NAUIMeter2Initialize(SOCKCB *scb, const char *message)
 }
 
 /**
- * @brief vOXo[1̍XV𑗐M
- * @param[in,out] scb \PbgubN
- * @param[in] message \bZ[W
- * @retval RET_OK I
- * @retval RET_SOCKET \PbgG[
- * @retval RET_ABORT f
- * @retval RET_TIMEOUT ^CAEg
- * @retval RET_NG ̑̃G[
+ * @brief プログレスバー1の更新を送信
+ * @param[in,out] scb ソケット制御ブロック
+ * @param[in] message 表示メッセージ
+ * @retval RET_OK 正常終了
+ * @retval RET_SOCKET ソケットエラー
+ * @retval RET_ABORT 中断
+ * @retval RET_TIMEOUT タイムアウト発生
+ * @retval RET_NG その他のエラー
  */
 int NAUIMeter1Update(SOCKCB *scb, float percentage)
 {
@@ -949,14 +950,14 @@ int NAUIMeter1Update(SOCKCB *scb, float percentage)
 }
 
 /**
- * @brief vOXo[2̍XV𑗐M
- * @param[in,out] scb \PbgubN
- * @param[in] message \bZ[W
- * @retval RET_OK I
- * @retval RET_SOCKET \PbgG[
- * @retval RET_ABORT f
- * @retval RET_TIMEOUT ^CAEg
- * @retval RET_NG ̑̃G[
+ * @brief プログレスバー2の更新を送信
+ * @param[in,out] scb ソケット制御ブロック
+ * @param[in] message 表示メッセージ
+ * @retval RET_OK 正常終了
+ * @retval RET_SOCKET ソケットエラー
+ * @retval RET_ABORT 中断
+ * @retval RET_TIMEOUT タイムアウト発生
+ * @retval RET_NG その他のエラー
  */
 int NAUIMeter2Update(SOCKCB *scb, float percentage)
 {
@@ -1022,10 +1023,10 @@ static const struct SOCKERRMESSAGE {
 #endif	/* WIN32 */
 
 /**
- * @brief G[R[hɑΉ郁bZ[W擾
- * @param[in] scb \PbgubN
- * @return 擾bZ[WԂBG[̏ꍇNULLԂB
- * @note 擾bZ[W̓KvȂB
+ * @brief エラーコードに対応するメッセージを取得
+ * @param[in] scb ソケット制御ブロック
+ * @return 取得したメッセージを返す。エラーの場合はNULLを返す。
+ * @note 取得したメッセージはメモリ解放する必要なし。
  */
 const char *NAGetErrorMessage(SOCKCB *scb)
 {
@@ -1047,27 +1048,22 @@ const char *NAGetErrorMessage(SOCKCB *scb)
 }
 
 /**
- * \Pbg֘AG[ȂG[\
- * @param[in]	drive	u\
- * @param[in]	ret_value ֐ԋpl
- * @return	\Pbg֘AG[ǂ
+ * ソケット関連エラーならエラーを表示
+ * @param[in]	drive	装置構造体
+ * @param[in]	ret_value 関数返却値
+ * @return	ソケット関連エラーかどうか
  */
 BOOL DispSocketError(SOCKCB *scb, int ret_value)
 {
 	if(ret_value==RET_SOCKET){
 		const char *message = NAGetErrorMessage(scb);
 		if(message != NULL){
-			char *net_err = (char *)MemNew(256);
-			if(net_err != NULL){
-				sprintf(net_err, MSG_NETWORK_ERROR_ /*"lbg[NG[ %ld : "*/,
-						scb->error_code);
-				net_err = (char *)MemResize(net_err, strlen(net_err)+strlen(message)+1);
-				if(net_err != NULL){
-					strcat(net_err, message);
-					UIDispMessage(message, UIDMT_ERROR);
-					MemFree(net_err);
-				}
-			}
+			char *net_err = EbStringNewWithFormat(
+				MSG_NETWORK_ERROR_ /*"ネットワークエラー %ld : "*/,
+				scb->error_code);
+			net_err = EbStringAppend(net_err, message);
+			UIDispMessage(message, UIDMT_ERROR);
+			net_err = EbStringFree(net_err);
 			return TRUE;
 		}
 	}
