@@ -4,13 +4,13 @@
 #define __STRUCT_H__
 
 /*
- * cdrecord/cdrtools Q
+ * cdrecord/cdrtools 参照
  * http://www.fokus.fhg.de/research/cc/glone/employees/joerg.schilling/private/cdrecord.html
  */
 
 #include "aspi.h"
 
-#if defined(WIN32) || defined(__i386__)
+#if defined(WIN32) || defined(__i386__) || defined(__x86_64__)
 #define BIT_FIELDS_LTOH	/* Intel */
 #endif
 
@@ -468,7 +468,12 @@ struct _TRACKINFO {
 	BYTE	res[2];					/* Reserved */
 #endif
 };
-
+#define SESSION_NUMBER(tp) \
+	((WORD)(tp)->session_number_msb<<8 |		\
+	 (WORD)(tp)->session_number_lsb)
+#define TRACK_NUMBER(tp) \
+	((WORD)(tp)->track_number_msb<<8 |			\
+	 (WORD)(tp)->track_number_lsb)
 
 struct _FEATURE_HEADER {	/* for GET CONFIGURATION */
 	BYTE	data_len[4];
@@ -534,14 +539,21 @@ struct _FORMATDESC {
 #endif
 };
 /* format_type */
-#define FDFT_FULL		0x10
-#define FDFT_GROW		0x11
-#define FDFT_ADD		0x12
-#define FDFT_QUICKGROW	0x13
-#define FDFT_QUICKADD	0x14
-#define FDFT_QUICK		0x15
-#define FDFT_CDMRW		0x24
-#define FDFT_DVDPRW		0x26
+#define FDFT_FULL		0x00	/* Full Format */
+#define FDFT_SPARE		0x01	/* Spare Area Expansion */
+#define FDFT_ZONERE		0x04	/* Zone Reformat */
+#define FDFT_ZONE		0x05	/* Zone Format */
+#define FDFT_CDVDFULL	0x10	/* CD/DVD-RW Full Format */
+#define FDFT_CDVDGROW	0x11	/* CD/DVD-RW Grow Session */
+#define FDFT_CDVDADD	0x12	/* CD/DVD-RW Add Session */
+#define FDFT_DVDQUICKGROW	0x13	/* DVD-RW Quick Grow */
+#define FDFT_DVDQUICKADD	0x14	/* DVD-RW Quick Add */
+#define FDFT_DVDQUICK		0x15	/* DVD-RW Quick */
+#define FDFT_CDMRW		0x24	/* MRW Full Format */
+#define FDFT_DVDPRW		0x26	/* DVD+RW Basic Format */
+#define FDFT_BDRESPARE	0x30	/* BD-RE Full Format With Spare */
+#define FDFT_BDRE		0x31	/* BD-RE Full Format */
+#define FDFT_BDRSPARE	0x32	/* CD-R Full Format With Spare */
 
 
 /* for READ FORMAT CAPACITIES */
@@ -642,35 +654,37 @@ struct _CUESHEET {
 
 
 
-/* fBXN^Cv */
-#define DT_UNKNOWN	0x0000	/* mfBXN */
+/* ディスクタイプ */
+#define DT_UNKNOWN	0x0000	/* 未知ディスク */
 #define DT_CDROM	0x0008	/* CD-ROM */
 #define DT_CDR		0x0009	/* CD-R */
 #define DT_CDRW		0x000A	/* CD-RW */
 #define DT_DVDROM	0x0010	/* DVD-ROM */
 #define DT_DVDR		0x0011	/* DVD-R */
 #define DT_DVDRAM	0x0012	/* DVD-RAM */
-#define DT_DVDRWO	0x0013	/* DVD-RW(tH[}bg) */
-#define DT_DVDRWS	0x0014	/* DVD-RW(V[PVL^) */
-#define DT_DVDRDL	0x0015	/* DVD-R Dual Layer(V[PVL^) */
-#define DT_DVDRDLJ	0x0016	/* DVD-R Dual Layer(C[WvL^) */
+#define DT_DVDRWO	0x0013	/* DVD-RW(フォーマット済) */
+#define DT_DVDRWS	0x0014	/* DVD-RW(シーケンシャル記録) */
+#define DT_DVDRDL	0x0015	/* DVD-R Dual Layer(シーケンシャル記録) */
+#define DT_DVDRDLJ	0x0016	/* DVD-R Dual Layer(レイヤージャンプ記録) */
 #define DT_DVDRWDL	0x0017	/* DVD-RW Dual Layer */
 #define DT_DVDPRW	0x001A	/* DVD+RW */
 #define DT_DVDPR	0x001B	/* DVD+R */
 #define DT_DVDPRWDL	0x002A	/* DVD+RW Dual Layer */
 #define DT_DVDPRDL	0x002B	/* DVD+R Dual Layer */
 #define DT_BDROM	0x0040	/* BD-ROM */
-#define DT_BDR		0x0041	/* BD-R(V[PVL^) */
-#define DT_BDRR		0x0042	/* BD-R(_L^) */
+#define DT_BDR		0x0041	/* BD-R(シーケンシャル記録) */
+#define DT_BDRR		0x0042	/* BD-R(ランダム記録) */
 #define DT_BDRE		0x0043	/* BD-RE */
 
-#define DT_CD_FAMILY(d)		(d==DT_CDROM||d==DT_CDR||d==DT_CDRW)
-#define DT_DVD_FAMILY(d)	(d>=DT_DVDROM)
+#define DT_CD_FAMILY(d)		((d)==DT_CDROM||(d)==DT_CDR||(d)==DT_CDRW)
+#define DT_DVD_FAMILY(d)	((d)>=DT_DVDROM&&(d)<DT_BDROM)
+#define DT_BD_FAMILY(d)		((d)>=DT_BDROM)
 #define DT_WRITABLE(d)		\
 	(d==DT_CDR||d==DT_CDRW||\
 	d==DT_DVDR||d==DT_DVDRWO||d==DT_DVDRWS||\
 	d==DT_DVDRDL||d==DT_DVDRDLJ||d==DT_DVDRWDL||\
 	d==DT_DVDPRW||d==DT_DVDPR||\
-	d==DT_DVDPRWDL||d==DT_DVDPRDL)
+	d==DT_DVDPRWDL||d==DT_DVDPRDL||\
+	d==DT_BDR||DT_BDRE)
 
 #endif /* !__STRUCT_H__ */
