@@ -1,9 +1,9 @@
-/*
+/**
  * @file text.h
- * @brief ϊ
+ * @brief 文字列変換
  * @author BananaJinn
- * @version $Id: text.h,v 1.12 2007/02/01 14:28:04 bananajinn Exp $
- * ~Օʉ
+ * @version $Id: text.h,v 1.16 2010/11/05 17:24:03 bananajinn Exp $
+ * 円盤複写屋
  * Copyright (C) 2004-2006 BananaJinn<banana@mxh.mesh.ne.jp>.
  */
 #ifndef __TEXT_H__
@@ -55,6 +55,7 @@ extern const char *GetText(const char *string);
 # define MSG_COMPLETE_SUCCESS GT("Process was complete successfully.")
 # define MSG_ERROR_OCCURRED GT("Error occurred.")
 # define MSG_ERROR_OCCURRED_CMDLOG GT("Error occurred. Create command log?")
+# define MSG_CMDLOG_WAS_SAVED_TO_ GT("Command log was saved to %s.")
 # define MSG_MEM_ALLOC_ERROR GT("Memory allocation error.")
 # define MSG_CANT_COPY_DIFFERENT_TYPE GT("Cannot copy onto a different disc type.")
 # define MSG_CANT_OPEN_IMAGE GT("Cannot open image file.")
@@ -63,7 +64,11 @@ extern const char *GetText(const char *string);
 # define MSG_CODE_CONV_ERROR GT("Code convert error.")
 # define MSG_UNKNOWN_COMMAND GT("Unknown command was received.")
 # define MSG_INVALID_IMAGE_FILE GT("Invalid image file.")
+# define MSG_MKISOFS_ERROR_ GT("Error occurred while executing mkisofs.\n%s")
+# define MSG_VIDEO_MODE GT("Do you want DVD-video mode?")
+
 #elif defined(WIN32)
+/* Windows用メッセージ */
 # include "resource.h"
 # define MSG_WAITING_READY GT(IDS_WAITING_READY)
 # define MSG_INSERT_DISC GT(IDS_INSERT_DISC)
@@ -100,6 +105,7 @@ extern const char *GetText(const char *string);
 # define MSG_COMPLETE_SUCCESS GT(IDS_COMPLETE_SUCCESS)
 # define MSG_ERROR_OCCURRED GT(IDS_ERROR_OCCURRED)
 # define MSG_ERROR_OCCURRED_CMDLOG GT(IDS_ERROR_OCCURRED_CMDLOG)
+# define MSG_CMDLOG_WAS_SAVED_TO_ GT(IDS_CMDLOG_WAS_SAVED_TO_)
 # define MSG_MEM_ALLOC_ERROR GT(IDS_MEM_ALLOC_ERROR)
 # define MSG_CANT_COPY_DIFFERENT_TYPE GT(IDS_CANT_COPY_DIFFERENT_TYPE)
 # define MSG_CANT_OPEN_IMAGE GT(IDS_CANT_OPEN_IMAGE)
@@ -108,6 +114,9 @@ extern const char *GetText(const char *string);
 # define MSG_CODE_CONV_ERROR GT(IDS_CODE_CONV_ERROR)
 # define MSG_UNKNOWN_COMMAND GT(IDS_UNKNOWN_COMMAND)
 # define MSG_INVALID_IMAGE_FILE GT(IDS_INVALID_IMAGE_FILE)
+# define MSG_MKISOFS_ERROR_ GT(IDS_MKISOFS_ERROR_)
+# define MSG_VIDEO_MODE GT(IDS_VIDEO_MODE)
+
 #endif
 
 #endif /* !__TEXT_H__ */
