@@ -1,10 +1,10 @@
 /**
  * @file filedlg.c
- * @brief Linux󥽡ǥե
+ * @brief Linuxコンソール版ファイル選択入力
  * @author BananaJinn
- * @version $Id: filedlg.c,v 1.4 2007/10/02 16:51:47 bananajinn Exp $
- * ʣ̲
- * Copyright (c) 2004-2007 Kagetani Hideto(BananaJinn)
+ * @version $Id: filedlg.c,v 1.5 2010/11/01 14:58:33 bananajinn Exp $
+ * 円盤複写屋
+ * Copyright (C) 2004-2010 BananaJinn<banana@mxh.mesh.ne.jp>
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -17,14 +17,14 @@
 #include "main.h"
 
 /**
- * @brief ե̾
- * @param[in] bOpen ե򳫤ξTRUE¸ξFALSE
- * @param[out] filename Ϥե̾
- * @param[in] size ե̾ǼХåեΥ
- * @param[in] suffix եޥȤĥ
- * @retval FDR_OK λ
- * @retval FDR_CANCEL 󥻥
- * @note ߤϤǤʤϤΤߡ
+ * @brief ファイル名選択入力
+ * @param[in] bOpen ファイルを開くための選択の場合はTRUE、保存の場合はFALSE
+ * @param[out] filename 選択入力したファイル名
+ * @param[in] size ファイル名を格納するバッファのサイズ
+ * @param[in] suffix ファイルマスクとする拡張子
+ * @retval FDR_OK 選択完了
+ * @retval FDR_CANCEL キャンセル
+ * @note 現在は選択はできない。入力のみ。
  */
 int FileDialog(int bOpen, char *filename, int size, const char *suffix)
 {
@@ -52,3 +52,17 @@ int FileDialog(int bOpen, char *filename, int size, const char *suffix)
   InputString(title, filename, size);
   return FDR_OK;
 }
+
+/**
+ * @brief フォルダ名入力
+ * @param[out] filename 入力したフォルダ名
+ * @param[in] size フォルダ名を格納するバッファのサイズ
+ * @retval FDR_OK 入力完了
+ * @retval FDR_CANCEL キャンセル
+ */
+int FolderDialog(char *filename, int size)
+{
+	const char *title = GT("select folder");
+	InputString(title, filename, size);
+	return FDR_OK;
+}
