@@ -1,10 +1,10 @@
 /**
  * @file main.c
- * @brief Linux󥽡ǥᥤ
+ * @brief Linuxコンソール版メイン
  * @author BananaJinn
- * @version $Id: main.c,v 1.5 2008/06/17 15:22:21 bananajinn Exp $
- * ʣ̲
- * Copyright (c) 2004-2007 Kagetani Hideto(BananaJinn)
+ * @version $Id: main.c,v 1.6 2010/11/01 14:58:33 bananajinn Exp $
+ * 円盤複写屋
+ * Copyright (C) 2004-2010 BananaJinn<banana@mxh.mesh.ne.jp>
  */
 
 #include <stdio.h>
@@ -37,13 +37,13 @@ static const char *g_tmpDir = NULL;
 static int g_batch = -1;
 
 /**
- * @brief ֥Ԥ桼򤷤֤֤
- * @param[out] ppDrives ̤Υɥ饤
- * @param[out] pNum ̤Υɥ饤ֿ(֤ξʣˤʤ)
- * @param[in] writer Ͽ֤Υ󤫤ɤ(Ͽξ0ʳ)
- * @param[in] pReader Ͽ֥ξɼ֤뤿ɼ֤ꤹ
- * @retval RET_OK 
- * @retval RET_NG 顼ȯ
+ * @brief 装置スキャンを行い、ユーザが選択した装置を返す。
+ * @param[out] ppDrives 選択結果のドライブ配列
+ * @param[out] pNum 選択結果のドライブ数(全書込装置の場合に複数になる)
+ * @param[in] writer 記録装置のスキャンかどうか(記録の場合は0以外を指定)
+ * @param[in] pReader 記録装置スキャンの場合に読取装置を除外するために読取装置を指定する
+ * @retval RET_OK 正常
+ * @retval RET_NG エラー発生
  */
 static int scan_drive(DRIVEID **ppDrives, int *pNum, BOOL writer,
 					  DRIVEID *pReader)
@@ -65,21 +65,23 @@ static int scan_drive(DRIVEID **ppDrives, int *pNum, BOOL writer,
 
 	if(writer){
 		printf("A : %s\n", GT("All devices that have inserted disc for record"));
-		/*"ϿѥǥѤ"*/
+		/*"記録用ディスク挿入済の全装置"*/
 	}
 	printf("I : %s\n", GT("ISO image file"));
-	/*"ISO᡼ե"*/
+	/*"ISOイメージファイル"*/
 	printf("E : %s\n", GT("Enban image file"));
-	/*"ץ᡼ե"*/
-	printf("N : %s\n", GT("Network"));	/* ͥåȥ */
-
+	/*"円盤イメージファイル"*/
+	printf("N : %s\n", GT("Network"));	/* ネットワーク */
+	if(!writer){
+		printf("M : %s\n", GT("ISO image from folder(mkisofs)"));
+	}
 	buf[0] = '\0';
 	while(1){
 		if(writer){
-			printf("%s=", GT("Writer"));  /*  */
+			printf("%s=", GT("Writer"));  /* 書込装置 */
 		}
 		else{
-			printf("%s=", GT("Reader"));  /* ɼ */
+			printf("%s=", GT("Reader"));  /* 読取装置 */
 		}
 
 		fgets(buf, sizeof(buf), stdin);
@@ -89,6 +91,9 @@ static int scan_drive(DRIVEID **ppDrives, int *pNum, BOOL writer,
 		if(buf[0]=='N' || buf[0]=='E' || buf[0]=='I'){
 			break;
 		}
+		if(!writer && buf[0]=='M'){
+			break;
+		}
 		if(atoi(buf) > 0){
 			break;
 		}
@@ -100,7 +105,7 @@ static int scan_drive(DRIVEID **ppDrives, int *pNum, BOOL writer,
 			if(pReader != NULL){
 				if(drives[count].hid == pReader->hid  &&
 				   drives[count].tid == pReader->tid){
-					/* ɼ̵֤ */
+					/* 読取装置は無視 */
 					continue;
 				}
 			}
@@ -122,25 +127,31 @@ static int scan_drive(DRIVEID **ppDrives, int *pNum, BOOL writer,
 			return RET_NG;
 		}
 		if(buf[0] == 'I'){
-			/* ISO᡼ */
+			/* ISOイメージ */
 			(*ppDrives)->hid = HID_VIRTUAL;
 			(*ppDrives)->tid = CMDDRVTYPE_ISO;
 			num_drive = 1;
 		}
 		else if(buf[0] == 'E'){
-			/* ץ᡼ */
+			/* 円盤イメージ */
 			(*ppDrives)->hid = HID_VIRTUAL;
 			(*ppDrives)->tid = CMDDRVTYPE_IMAGE;
 			num_drive = 1;
 		}
 		else if(buf[0] == 'N'){
-			/* ͥåȥ */
+			/* ネットワーク */
 			(*ppDrives)->hid = HID_VIRTUAL;
 			(*ppDrives)->tid = CMDDRVTYPE_NET;
 			num_drive = 1;
 		}
+		else if(buf[0] == 'M'){
+			/* mkisofs */
+			(*ppDrives)->hid = HID_VIRTUAL;
+			(*ppDrives)->tid = CMDDRVTYPE_MKISOFS;
+			num_drive = 1;
+		}
 		else{
-			/* ̾Υɥ饤 */
+			/* 通常のドライブ */
 			index = atoi(buf)-1;
 			if((index >= 0) && (index < count)){
 				(*ppDrives)->hid = drives[index].hid;
@@ -161,9 +172,9 @@ static int scan_drive(DRIVEID **ppDrives, int *pNum, BOOL writer,
 }
 
 /**
- * @brief ǥХʸ󤫤DRIVEID
- * @param[in] dev ǥХʸ
- * @return DRIVEIDΥݥ󥿤ݤ֤
+ * @brief デバイス文字列からDRIVEIDを求める
+ * @param[in] dev デバイス文字列
+ * @return DRIVEID型のポインタをメモリ確保して返す。
  */
 DRIVEID *GetDriveIDFromDeviceString(const char *dev)
 {
@@ -182,7 +193,7 @@ DRIVEID *GetDriveIDFromDeviceString(const char *dev)
 		return id;
 	}
 	if(strchr(dev, ':') != NULL){
-		/* ͥåȥ */
+		/* ネットワーク */
 		id->hid = HID_VIRTUAL;
 		id->tid = CMDDRVTYPE_NET;
 		return id;
@@ -205,9 +216,9 @@ DRIVEID *GetDriveIDFromDeviceString(const char *dev)
 }
 
 /**
- * @brief ʣ̳
- * @param[in] arg_reader ɼֻ
- * @param[in] arg_writer ֻ
+ * @brief 複写開始
+ * @param[in] arg_reader 読取装置指定
+ * @param[in] arg_writer 書込装置指定
  */
 void start_copy(const char *arg_reader, const char *arg_writer)
 {
@@ -225,7 +236,7 @@ void start_copy(const char *arg_reader, const char *arg_writer)
 		}
 	}
 	if(pReader == NULL){
-		/* ɼ */
+		/* 読取装置選択 */
 		if(scan_drive(&pReader, &reader_num, FALSE, NULL) != RET_OK){
 			printf("%s\n", GT("Error in the initialization of the drive."));
 			return;
@@ -242,7 +253,7 @@ void start_copy(const char *arg_reader, const char *arg_writer)
 		}
 	}
 	if(pWriter == NULL){
-		/*  */
+		/* 書込装置選択 */
 		if(scan_drive(&pWriter, &writer_num, TRUE, pReader) != RET_OK){
 			printf("%s\n", GT("Error in the initialization of then writer drive."));
 			free(pReader);
@@ -250,7 +261,7 @@ void start_copy(const char *arg_reader, const char *arg_writer)
 		}
 	}
 
-	/* ʣ̼¹ */
+	/* 複写実行 */
 	ret = CopyDisc(pReader, pWriter, writer_num);
   
 	free(pReader);
@@ -397,11 +408,11 @@ main (int argc, char *argv[])
 
 
 /**
- * ؿ
+ * 外部公開関数
  */
 
 /**
- * @brief ǻꤵ줿ɼ̾
+ * @brief 引数で指定された読取装置名を取得
  */
 const char *GetArgReader()
 {
@@ -409,7 +420,7 @@ const char *GetArgReader()
 }
 
 /**
- * @brief ǻꤵ줿̾
+ * @brief 引数で指定された書込装置名を取得
  */
 const char *GetArgWriter()
 {
@@ -417,7 +428,7 @@ const char *GetArgWriter()
 }
 
 /**
- * @brief ǻꤵ줿ɹ®٤
+ * @brief 引数で指定された読込速度を取得
  */
 int GetArgReadSpeed()
 {
@@ -425,7 +436,7 @@ int GetArgReadSpeed()
 }
 
 /**
- * @brief ǻꤵ줿®٤
+ * @brief 引数で指定された書込速度を取得
  */
 int GetArgWriteSpeed()
 {
@@ -433,7 +444,7 @@ int GetArgWriteSpeed()
 }
 
 /**
- * @brief ǻꤵ줿ƥȵϿ
+ * @brief 引数で指定されたテスト記録指定を取得
  */
 int GetArgTestWrite()
 {
@@ -441,7 +452,7 @@ int GetArgTestWrite()
 }
 
 /**
- * @brief ǻꤵ줿BUFE
+ * @brief 引数で指定されたBUFE指定を取得
  */
 int GetArgBUFE()
 {
@@ -449,7 +460,7 @@ int GetArgBUFE()
 }
 
 /**
- * @brief ǻꤵ줿OnTheFly
+ * @brief 引数で指定されたOnTheFly指定を取得
  */
 int GetArgOnTheFly()
 {
@@ -457,7 +468,7 @@ int GetArgOnTheFly()
 }
 
 /**
- * @brief ǻꤵ줿¦Ͽ⡼ɻ
+ * @brief 引数で指定された外側記録モード指定を取得
  */
 int GetArgOutside()
 {
@@ -465,7 +476,7 @@ int GetArgOutside()
 }
 
 /**
- * @brief ǻꤵ줿DAO
+ * @brief 引数で指定されたDAO指定を取得
  */
 int GetArgDAO()
 {
@@ -473,7 +484,7 @@ int GetArgDAO()
 }
 
 /**
- * @brief ǻꤵ줿ǥ쥯ȥ
+ * @brief 引数で指定された一時ディレクトリを取得
  */
 const char *GetArgTempDirectory()
 {
@@ -481,7 +492,7 @@ const char *GetArgTempDirectory()
 }
 
 /**
- * @brief ǻꤵ줿Хå⡼ɻ
+ * @brief 引数で指定されたバッチモード指定を取得
  */
 int GetArgBatchMode()
 {
