@@ -1,10 +1,10 @@
 /**
  * @file messagebox.h
- * @brief Linux󥽡ǥå
+ * @brief Linuxコンソール版メッセージ出力
  * @author BananaJinn
- * @version $Id: messagebox.h,v 1.2 2007/09/26 15:35:44 bananajinn Exp $
- * ʣ̲
- * Copyright (c) 2004-2007 Kagetani Hideto(BananaJinn)
+ * @version $Id: messagebox.h,v 1.3 2010/11/01 14:58:33 bananajinn Exp $
+ * 円盤複写屋
+ * Copyright (C) 2004-2010 BananaJinn<banana@mxh.mesh.ne.jp>
  */
 #ifndef __MESSAGEBOX_H__
 #define __MESSAGEBOX_H__
@@ -20,11 +20,11 @@
 
 /* Flags */
 #define MBF_TYPEMASK		0x000f
-#define MBF_TYPEABORTRETRYIGNORE 0x0001	/* /ƻ/̵ */
-#define MBF_TYPEOKCANCEL	0x0002  /* OK/󥻥 */
-#define MBF_TYPERETRYCANCEL	0x0003  /* ƻ/󥻥 */
-#define MBF_TYPEYESNO		0x0004  /* Ϥ/ */
-#define MBF_TYPEYESNOCANCEL	0x0005  /* Ϥ//󥻥 */
+#define MBF_TYPEABORTRETRYIGNORE 0x0001	/* 中止/再試行/無視 */
+#define MBF_TYPEOKCANCEL	0x0002  /* OK/キャンセル */
+#define MBF_TYPERETRYCANCEL	0x0003  /* 再試行/キャンセル */
+#define MBF_TYPEYESNO		0x0004  /* はい/いいえ */
+#define MBF_TYPEYESNOCANCEL	0x0005  /* はい/いいえ/キャンセル */
 #define MBF_TYPEOK		0x0006  /* OK */
 
 #define MBF_ICONMASK		0x00f0
