@@ -1,10 +1,10 @@
 /**
  * @file netdlg.h
- * @brief ͥåȥ
+ * @brief ネットワーク設定入力
  * @author BananaJinn
- * @version $Id: netdlg.c,v 1.4 2007/10/02 16:51:47 bananajinn Exp $
- * ʣ̲
- * Copyright (c) 2004-2007 Kagetani Hideto(BananaJinn)
+ * @version $Id: netdlg.c,v 1.5 2010/11/01 14:58:33 bananajinn Exp $
+ * 円盤複写屋
+ * Copyright (C) 2004-2010 BananaJinn<banana@mxh.mesh.ne.jp>
  */
 #include <stdio.h>
 #include <stdlib.h>
@@ -58,10 +58,10 @@ int NetDialog(int bServer, char *remote, int size, int *port_number)
   }
 
   if(!bServer){
-	  InputString(GT("Connect host") /* ³襢ɥ쥹 */,
+	  InputString(GT("Connect host") /* 接続先アドレス */,
 				  remote, size);
   }
-  InputNumber(GT("Port number") /* ݡֹ */,
+  InputNumber(GT("Port number") /* ポート番号 */,
 	      port_number);
 
   return NDR_OK;
