@@ -1,10 +1,10 @@
 /**
  * @file ui.h
- * @brief Linux󥽡ǥ桼󥿡ե
+ * @brief Linuxコンソール版ユーザインターフェース
  * @author BananaJinn
- * @version $Id: ui.h,v 1.2 2007/09/26 15:35:44 bananajinn Exp $
- * ʣ̲
- * Copyright (C) 2004-2007 Kagetani Hideto(BananaJinn)
+ * @version $Id: ui.h,v 1.3 2010/11/01 14:58:33 bananajinn Exp $
+ * 円盤複写屋
+ * Copyright (C) 2004-2010 BananaJinn<banana@mxh.mesh.ne.jp>
  */
 
 #ifndef __UI_H__
@@ -30,6 +30,7 @@ extern void UIMeter1Update(float percentage);
 extern void UIMeter2Update(float percentage);
 extern void UIDispInfo(const char *message);
 extern int UIFileDialog(BOOL bOpen, char *filename, int size, const char *suffix);
+extern int UIFolderDialog(char *filename, int size);
 extern int UINetDialog(BOOL bServer, char *remote, int size, int *port_number);
 extern int UISetting(OPTIONS *option);
 
