@@ -1,18 +1,23 @@
 #!/bin/bash
 PROG=EnbanFukusyaYa
 TMPDIR=/tmp/$PROG
+RPMTOP=$HOME/rpmbuild
+RPMBUILD=rpmbuild
 if [ -e /etc/vine-release ]; then
-  RPMTOP=/usr/src/vine
-  RPMBUILD=rpm
-  grep -q 4\. /etc/vine-release \
-    && SPECFILE=$PROG-vl4.spec \
-    || SPECFILE=$PROG.spec
+  SPECFILE=$PROG-vl.spec
 else
-  RPMTOP=/usr/src/redhat
-  RPMBUILD=rpmbuild
   SPECFILE=$PROG-fc.spec
 fi
 
+if [ -f $HOME/.rpmmacros ]; then
+  _RPMTOP=$(grep ^%_topdir $HOME/.rpmmacros)
+  _RPMTOP=${_RPMTOP#*\ }
+  eval _RPMTOP=$_RPMTOP
+  if [ "$_RPMTOP" != "" ] && [ -d $_RPMTOP ]; then
+    RPMTOP=$_RPMTOP
+  fi
+fi
+
 SOURCE=`grep ^Source: $SPECFILE`
 SOURCEFILE=${SOURCE##*:\ }
 VERSION=`grep ^Version: $SPECFILE`
@@ -34,3 +39,4 @@ cp $SPECFILE $RPMTOP/SPECS/
 mv $TMPDIR/$SOURCEFILE $RPMTOP/SOURCES/
 
 $RPMBUILD -ba $RPMTOP/SPECS/$SPECFILE
+$RPMBUILD --target i386 -ba $RPMTOP/SPECS/$SPECFILE
