@@ -1,6 +1,9 @@
 /**
- * ʣ̲
- * Copyright (C) 2004-2008 Kagetani Hideto(banana@mxh.mesh.ne.jp)
+ * @file main.c
+ * @auther BananaJinn
+ * @version $Id: main.c,v 1.16 2010/11/01 14:34:11 bananajinn Exp $
+ * 円盤複写屋
+ * Copyright (C) 2004-2010 BananaJinn<banana@mxh.mesh.ne.jp>
  */
 
 #include <stdio.h>
@@ -35,6 +38,7 @@ static int g_ReaderEmg = -1;
 static int g_WriterEmg = -1;
 static int g_ReaderNet = -1;
 static int g_WriterNet = -1;
+static int g_ReaderMkisofs = -1;
 static const char *g_argReader = NULL;
 static const char *g_argWriter = NULL;
 
@@ -48,10 +52,18 @@ const char *GetArgWriter()
 	return g_argWriter;
 }
 
+static void add_menuitem(GtkWidget *menu, const char *name, int number)
+{
+	GtkWidget *menuitem;
+	menuitem = gtk_menu_item_new_with_label(name);
+	gtk_object_set_user_data(GTK_OBJECT(menuitem), GINT_TO_POINTER(number));
+	gtk_menu_append(GTK_MENU(menu), menuitem);
+	gtk_widget_show(menuitem);
+}
+
 static int scan_drive(GtkWidget *optmenu, BOOL writer)
 {
 	GtkWidget *menu;
-	GtkWidget *menuitem;
 	SCAN_t *drives;
 	int count;
 	int sel = -1;
@@ -65,18 +77,13 @@ static int scan_drive(GtkWidget *optmenu, BOOL writer)
 	menu = gtk_menu_new();
 
 	for(count=0; strlen((char *)drives[count].inqdata)!=0; count++){
-		menuitem = gtk_menu_item_new_with_label((char *)drives[count].inqdata);
-		gtk_object_set_user_data(GTK_OBJECT(menuitem), GINT_TO_POINTER(count));
-		gtk_menu_append(GTK_MENU(menu), menuitem);
-		gtk_widget_show(menuitem);
+		add_menuitem(menu, (char *)drives[count].inqdata, count);
 	}
 
 	if(writer){
-		menuitem = gtk_menu_item_new_with_label(GT("All devices that have inserted disc for record")
-												/*"ϿѥǥѤ"*/);
-		gtk_object_set_user_data(GTK_OBJECT(menuitem), GINT_TO_POINTER(count));
-		gtk_menu_append(GTK_MENU(menu), menuitem);
-		gtk_widget_show(menuitem);
+		add_menuitem(menu, GT("All devices that have inserted disc for record"),
+					 /* "記録用ディスク挿入済の全装置" */
+					 count);
 		g_AllWritableDrives = count;
 		count++;
 	}
@@ -86,17 +93,14 @@ static int scan_drive(GtkWidget *optmenu, BOOL writer)
 #define IS_DEVICE_EMG(s) \
 		((strlen(s) > 4) && (strcasecmp(s+strlen(s)-4, ".emg")==0))
 	const char *dev = writer ? g_argWriter : g_argReader;
-	const char *name = GT("ISO image file"); /* ISO᡼ե */
+	const char *name = GT("ISO image file"); /* ISOイメージファイル */
 	if(dev != NULL){
 		if(IS_DEVICE_ISO(dev)){
 			name = dev;
 			sel = count;
 		}
 	}
-	menuitem = gtk_menu_item_new_with_label(name);
-	gtk_object_set_user_data(GTK_OBJECT(menuitem), GINT_TO_POINTER(count));
-	gtk_menu_append(GTK_MENU(menu), menuitem);
-	gtk_widget_show(menuitem);
+	add_menuitem(menu, name, count);
 	if(writer){
 		g_WriterISO = count;
 	}
@@ -105,17 +109,14 @@ static int scan_drive(GtkWidget *optmenu, BOOL writer)
 	}
 	count++;
 
-	name = GT("Enban image file"); /* ץ᡼ե */
+	name = GT("Enban image file"); /* 円盤イメージファイル */
 	if(dev != NULL){
 		if(IS_DEVICE_EMG(dev)){
 			name = dev;
 			sel = count;
 		}
 	}
-	menuitem = gtk_menu_item_new_with_label(name);
-	gtk_object_set_user_data(GTK_OBJECT(menuitem), GINT_TO_POINTER(count));
-	gtk_menu_append(GTK_MENU(menu), menuitem);
-	gtk_widget_show(menuitem);
+	add_menuitem(menu, name, count);
 	if(writer){
 		g_WriterEmg = count;
 	}
@@ -124,10 +125,7 @@ static int scan_drive(GtkWidget *optmenu, BOOL writer)
 	}
 	count++;
 
-	menuitem = gtk_menu_item_new_with_label(GT("Network")/*"ͥåȥ"*/);
-	gtk_object_set_user_data(GTK_OBJECT(menuitem), GINT_TO_POINTER(count));
-	gtk_menu_append(GTK_MENU(menu), menuitem);
-	gtk_widget_show(menuitem);
+	add_menuitem(menu, GT("Network"), count);
 	if(writer){
 		g_WriterNet = count;
 	}
@@ -136,6 +134,12 @@ static int scan_drive(GtkWidget *optmenu, BOOL writer)
 	}
 	count++;
 
+	if(!writer){
+		add_menuitem(menu, GT("ISO image from folder(mkisofs)"), count);
+		g_ReaderMkisofs = count;
+		count++;
+	}
+
 	gtk_option_menu_set_menu(GTK_OPTION_MENU(optmenu), menu);
 
 	if(writer)
@@ -182,7 +186,7 @@ on_btnStartCopy_clicked(GtkWidget *widget, gpointer user_data)
 		return;
 	}
 
-	/* ɥ饤ּ */
+	/* 選択ドライブ取得 */
 	menu = gtk_option_menu_get_menu(GTK_OPTION_MENU(g_optMenu1));
 	menuitem = gtk_menu_get_active(GTK_MENU(menu));
 	sel_reader = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(menuitem)));
@@ -191,28 +195,28 @@ on_btnStartCopy_clicked(GtkWidget *widget, gpointer user_data)
 	menuitem = gtk_menu_get_active(GTK_MENU(menu));
 	sel_writer = GPOINTER_TO_INT(gtk_object_get_user_data(GTK_OBJECT(menuitem)));
 
-	/* ѥ */
+	/* 書込装置用メモリ確保 */
 	writerp = (DRIVEID *)malloc(sizeof(DRIVEID));
 	if(writerp==NULL){
 		MessageBoxDlg(GT("Error in the initialization of the drive.")
-					  /*"֤ν˼Ԥޤ(ݥ顼)"*/, NULL,
+					  /*"装置の初期化に失敗しました。(メモリ確保エラー)"*/, NULL,
 					  MBF_TYPEOK|MBF_ICONSTOP);
 		return;
 	}
 
-	/*  */
+	/* 書込装置設定 */
 	if(sel_writer == g_AllWritableDrives){
 		writer_num = 0;
 		for(index=0; strlen((char *)g_WriterList[index].inqdata)!=0; index++){
 			if(g_ReaderList[sel_reader].hid == g_WriterList[index].hid &&
 			   g_ReaderList[sel_reader].tid == g_WriterList[index].tid){
-				/* ɼ̵֤ */
+				/* 読取装置は無視 */
 				continue;
 			}
 			writerp = (DRIVEID *)realloc(writerp, (writer_num+1)*sizeof(DRIVEID));
 			if(writerp == NULL){
 				MessageBoxDlg(GT("Error in the initialization of the writer drive.")
-							  /*"֤ν˼Ԥޤ(ݥ顼)"*/,
+							  /*"書込装置の初期化に失敗しました。(メモリ確保エラー)"*/,
 							  NULL,
 							  MBF_TYPEOK|MBF_ICONSTOP);
 				return;
@@ -243,8 +247,12 @@ on_btnStartCopy_clicked(GtkWidget *widget, gpointer user_data)
 		writer_num = 1;
 	}
 
-	/* ɹ */
-	if(sel_reader == g_ReaderISO){
+	/* 読込装置設定 */
+	if(sel_reader == g_ReaderMkisofs){
+		reader.hid = HID_VIRTUAL;
+		reader.tid = CMDDRVTYPE_MKISOFS;
+	}
+	else if(sel_reader == g_ReaderISO){
 		reader.hid = HID_VIRTUAL;
 		reader.tid = CMDDRVTYPE_ISO;
 	}
@@ -268,7 +276,7 @@ on_btnStartCopy_clicked(GtkWidget *widget, gpointer user_data)
 	gtk_widget_set_sensitive(g_optMenu1, FALSE);
 	gtk_widget_set_sensitive(g_optMenu2, FALSE);
 	gtk_label_set_text(GTK_LABEL(GTK_BIN(g_btnStartCopy)->child),
-					   GT("Cancel")/*""*/);
+					   GT("Cancel")/*"中止"*/);
 
 	ret = CopyDisc(&reader, writerp, writer_num);
   
@@ -277,10 +285,10 @@ on_btnStartCopy_clicked(GtkWidget *widget, gpointer user_data)
 	gtk_widget_set_sensitive(g_optMenu1, TRUE);
 	gtk_widget_set_sensitive(g_optMenu2, TRUE);
 	gtk_label_set_text(GTK_LABEL(GTK_BIN(g_btnStartCopy)->child),
-					   GT("Start")/*"ʣ̳"*/);
+					   GT("Start")/*"複写開始"*/);
 	g_bRunningCopy = FALSE;
   
-	/* ֥ */
+	/* 書込装置メモリ解放 */
 	free(writerp);
 
 	UIMeter1Initialize(NULL);
@@ -330,12 +338,12 @@ create_mainwindow(void)
 	GdkColormap *colormap;
 	char ver_buf[32];
 
-	/* ᥤ󥦥ɥ */
+	/* メインウィンドウ */
 	window1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_object_set_data (GTK_OBJECT (window1), "window1", window1);
 	gtk_window_set_title (GTK_WINDOW (window1), GT("EnbanFukusyaYa")
-						  /*"ʣ̲"*/);
-	/* ơ֥ */
+						  /*"円盤複写屋"*/);
+	/* テーブル */
 	table1 = gtk_table_new (7, 3, FALSE);
 	gtk_widget_ref (table1);
 	gtk_object_set_data_full (GTK_OBJECT (window1), "table1", table1,
@@ -346,7 +354,7 @@ create_mainwindow(void)
 	gtk_table_set_row_spacings (GTK_TABLE (table1), 5);
 	gtk_table_set_col_spacings (GTK_TABLE (table1), 5);
 
-	/*  */
+	/* ロゴ */
 	colormap = gtk_widget_get_colormap (window1);
 	gdkpixmap = gdk_pixmap_colormap_create_from_xpm_d(NULL, colormap, &mask,
 													  NULL, logo_xpm);
@@ -365,7 +373,7 @@ create_mainwindow(void)
   
 	table_line++;
 
-	/* С */
+	/* バージョン情報 */
 	sprintf(ver_buf, "Version %s", VERSION);
 	label_ver = gtk_label_new(ver_buf);
 	gtk_widget_ref(label_ver);
@@ -379,8 +387,8 @@ create_mainwindow(void)
 	gtk_misc_set_alignment(GTK_MISC(label_ver), 0.5, 0.5);
 	table_line++;
 
-	/* ٥ */
-	label1 = gtk_label_new (GT("Reader")/*"ɼ"*/);
+	/* ラベル */
+	label1 = gtk_label_new (GT("Reader")/*"読取装置"*/);
 	gtk_widget_ref (label1);
 	gtk_object_set_data_full (GTK_OBJECT (window1), "label1", label1,
 							  (GtkDestroyNotify) gtk_widget_unref);
@@ -391,7 +399,7 @@ create_mainwindow(void)
 					  (GtkAttachOptions) (0), 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (label1), 0, 0.5);
 
-	/* ɹ֥ץ˥塼 */
+	/* 読込装置オプションメニュー */
 	optionmenu1 = gtk_option_menu_new ();
 	gtk_widget_ref (optionmenu1);
 	gtk_object_set_data_full (GTK_OBJECT (window1), "optionmenu1", optionmenu1,
@@ -405,8 +413,8 @@ create_mainwindow(void)
 	optionmenu1_menu = gtk_menu_new ();
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu1), optionmenu1_menu);
 
-	/* ʣ̳ϥܥ */
-	btnStartCopy = gtk_button_new_with_label (GT("Start")/*"ʣ̳"*/);
+	/* 複写開始ボタン */
+	btnStartCopy = gtk_button_new_with_label (GT("Start")/*"複写開始"*/);
 	gtk_widget_ref (btnStartCopy);
 	gtk_object_set_data_full (GTK_OBJECT (window1), "btnStartCopy", btnStartCopy,
 							  (GtkDestroyNotify) gtk_widget_unref);
@@ -418,8 +426,8 @@ create_mainwindow(void)
 
 	table_line++;
 
-	/* ٥ */
-	label2 = gtk_label_new (GT("Writer")/*""*/);
+	/* ラベル */
+	label2 = gtk_label_new (GT("Writer")/*"書込装置"*/);
 	gtk_widget_ref (label2);
 	gtk_object_set_data_full (GTK_OBJECT (window1), "label2", label2,
 							  (GtkDestroyNotify) gtk_widget_unref);
@@ -431,7 +439,7 @@ create_mainwindow(void)
 	gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
 
 
-	/* ֥ץ˥塼 */
+	/* 書込装置オプションメニュー */
 	optionmenu2 = gtk_option_menu_new ();
 	gtk_widget_ref (optionmenu2);
 	gtk_object_set_data_full (GTK_OBJECT (window1), "optionmenu2", optionmenu2,
@@ -445,8 +453,8 @@ create_mainwindow(void)
 	optionmenu2_menu = gtk_menu_new ();
 	gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu1), optionmenu2_menu);
 
-	/* λܥ */
-	btnExit = gtk_button_new_with_label (GT("Quit")/*"λ"*/);
+	/* 終了ボタン */
+	btnExit = gtk_button_new_with_label (GT("Quit")/*"終了"*/);
 	gtk_widget_ref (btnExit);
 	gtk_object_set_data_full (GTK_OBJECT (window1), "btnExit", btnExit,
 							  (GtkDestroyNotify) gtk_widget_unref);
@@ -458,8 +466,8 @@ create_mainwindow(void)
 
 	table_line++;
 
-	/* ٥ */
-	label3 = gtk_label_new (GT("Total")/*""*/);
+	/* ラベル */
+	label3 = gtk_label_new (GT("Total")/*"全体"*/);
 	gtk_widget_ref (label3);
 	gtk_object_set_data_full (GTK_OBJECT (window1), "label3", label3,
 							  (GtkDestroyNotify) gtk_widget_unref);
@@ -470,7 +478,7 @@ create_mainwindow(void)
 					  (GtkAttachOptions) (0), 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (label3), 0, 0.5);
 
-	/* ĽС1 */
+	/* 進捗バー1 */
 	progressbar1 = gtk_progress_bar_new ();
 	gtk_widget_ref (progressbar1);
 	gtk_object_set_data_full (GTK_OBJECT (window1), "progressbar1", progressbar1,
@@ -483,8 +491,8 @@ create_mainwindow(void)
 
 	table_line++;
 
-	/* ٥ */
-	label4 = gtk_label_new (GT("Track")/*"ȥå"*/);
+	/* ラベル */
+	label4 = gtk_label_new (GT("Track")/*"トラック"*/);
 	gtk_widget_ref (label4);
 	gtk_object_set_data_full (GTK_OBJECT (window1), "label4", label4,
 							  (GtkDestroyNotify) gtk_widget_unref);
@@ -495,7 +503,7 @@ create_mainwindow(void)
 					  (GtkAttachOptions) (0), 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (label4), 0, 0.5);
 
-	/* ĽС2 */
+	/* 進捗バー2 */
 	progressbar2 = gtk_progress_bar_new ();
 	gtk_widget_ref (progressbar2);
 	gtk_object_set_data_full (GTK_OBJECT (window1), "progressbar2", progressbar2,
@@ -507,7 +515,7 @@ create_mainwindow(void)
 					  (GtkAttachOptions) (0), 0, 0);
 
 	table_line++;
-	/* ɽѥ٥ */
+	/* 情報表示用ラベル */
 	label_info = gtk_label_new("");
 	gtk_widget_ref(label_info);
 	gtk_object_set_data_full(GTK_OBJECT(window1), "label_info", label_info,
