@@ -1,5 +1,9 @@
-/* ʣ̲
- * Copyright (c) 2004 Kagetani Hideto
+/**
+ * @file messagebox.c
+ * @author BananaJinn
+ * @version $Id: messagebox.c,v 1.3 2010/11/01 14:34:11 bananajinn Exp $
+ * 円盤複写屋
+ * Copyright (C) 2004-2010 BananaJinn<banana@mxh.mesh.ne.jp>
  */
 #include <gtk/gtk.h>
 #include <stdio.h>
@@ -22,7 +26,7 @@ static GtkWidget* create_MessageBox (const char *message, const char *title, gui
 gint16 MessageBoxDlg(const char *message, const char *title, guint16 flags)
 {
   if(title==NULL)
-    title=GT("EnbanFukusyaYa")/*"ʣ̲"*/;
+    title=GT("EnbanFukusyaYa")/*"円盤複写屋"*/;
 
   g_Done = FALSE;
 
@@ -80,37 +84,37 @@ create_MessageBox (const char *message, const char *title, guint16 flags)
 
   switch(flags & MBF_TYPEMASK){
   case MBF_TYPEABORTRETRYIGNORE:
-    button1label = GT("Abort")/*""*/;
-    button2label = GT("Retry")/*"ƻ"*/;
-    button3label = GT("Ignore")/*"̵"*/;
+    button1label = GT("Abort")/*"中止"*/;
+    button2label = GT("Retry")/*"再試行"*/;
+    button3label = GT("Ignore")/*"無視"*/;
     g_RetCodes[0] = MBR_ABORT;
     g_RetCodes[1] = MBR_RETRY;
     g_RetCodes[2] = MBR_IGNORE;
     break;
   case MBF_TYPEOKCANCEL:
     button2label = GT("OK")/*"OK"*/;
-    button3label = GT("Cancel")/*"󥻥"*/;
+    button3label = GT("Cancel")/*"キャンセル"*/;
     g_RetCodes[0] = 0;
     g_RetCodes[1] = MBR_OK;
     g_RetCodes[2] = MBR_CANCEL;
     break;
   case MBF_TYPERETRYCANCEL:
-    button2label = GT("Retry")/*"ƻ"*/;
-    button3label = GT("Cancel")/*"󥻥"*/;
+    button2label = GT("Retry")/*"再試行"*/;
+    button3label = GT("Cancel")/*"キャンセル"*/;
     g_RetCodes[0] = 0;
     g_RetCodes[1] = MBR_RETRY;
     g_RetCodes[2] = MBR_CANCEL;
   case MBF_TYPEYESNO:
-    button2label = GT("Yes")/*"Ϥ"*/;
-    button3label = GT("No")/*""*/;
+    button2label = GT("Yes")/*"はい"*/;
+    button3label = GT("No")/*"いいえ"*/;
     g_RetCodes[0] = 0;
     g_RetCodes[1] = MBR_YES;
     g_RetCodes[2] = MBR_NO;
     break;
   case MBF_TYPEYESNOCANCEL:
-    button1label = GT("Yes")/*"Ϥ"*/;
-    button2label = GT("No")/*""*/;
-    button3label = GT("Cancel")/*"󥻥"*/;
+    button1label = GT("Yes")/*"はい"*/;
+    button2label = GT("No")/*"いいえ"*/;
+    button3label = GT("Cancel")/*"キャンセル"*/;
     g_RetCodes[0] = MBR_YES;
     g_RetCodes[1] = MBR_NO;
     g_RetCodes[2] = MBR_CANCEL;
@@ -159,7 +163,7 @@ create_MessageBox (const char *message, const char *title, guint16 flags)
   gtk_widget_show (hbox2);
   gtk_box_pack_start (GTK_BOX (dialog_vbox1), hbox2, TRUE, TRUE, 0);
 
-  /*  */
+  /* アイコン */
   colormap = gtk_widget_get_colormap(MessageBox);
   gdkpixmap = gdk_pixmap_colormap_create_from_xpm_d(NULL, colormap, &mask,
 						    NULL, icondata);
