@@ -1,5 +1,9 @@
-/* ʣ̲
- * Copyright (c) 2004 Kagetani Hideto
+/**
+ * @file netdlg.c
+ * @author BananaJinn
+ * @version $Id: netdlg.c,v 1.4 2010/11/01 14:34:11 bananajinn Exp $
+ * 円盤複写屋
+ * Copyright (C) 2004-2010 BananaJinn<banana@mxh.mesh.ne.jp>
  */
 #include <gtk/gtk.h>
 #include <stdio.h>
@@ -71,7 +75,7 @@ create_net_dialog(void)
   gtk_table_set_row_spacings (GTK_TABLE (table1), 5);
   gtk_table_set_col_spacings (GTK_TABLE (table1), 5);
 
-  label_address = gtk_label_new (GT("Connect host")/*"³襢ɥ쥹"*/);
+  label_address = gtk_label_new (GT("Connect host")/*"接続先アドレス"*/);
   gtk_widget_ref (label_address);
   gtk_object_set_data_full (GTK_OBJECT (netdlg), "label_address", label_address,
                             (GtkDestroyNotify) gtk_widget_unref);
@@ -81,7 +85,7 @@ create_net_dialog(void)
                     (GtkAttachOptions) (0), 0, 0);
   gtk_misc_set_alignment (GTK_MISC (label_address), 0, 0.5);
 
-  label_port = gtk_label_new (GT("Port number")/*"ݡֹ"*/);
+  label_port = gtk_label_new (GT("Port number")/*"ポート番号"*/);
   gtk_widget_ref (label_port);
   gtk_object_set_data_full (GTK_OBJECT (netdlg), "label_port", label_port,
                             (GtkDestroyNotify) gtk_widget_unref);
@@ -91,7 +95,7 @@ create_net_dialog(void)
                     (GtkAttachOptions) (0), 0, 0);
   gtk_misc_set_alignment (GTK_MISC (label_port), 0, 0.5);
 
-	  /* ³襢ɥ쥹 */
+	  /* 接続先アドレス入力 */
   entry_address = gtk_entry_new ();
   gtk_widget_ref (entry_address);
   gtk_object_set_data_full (GTK_OBJECT (netdlg), "entry_address", entry_address,
@@ -100,7 +104,7 @@ create_net_dialog(void)
   gtk_table_attach (GTK_TABLE (table1), entry_address, 1, 2, 0, 1,
                     (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                     (GtkAttachOptions) (0), 0, 0);
-	  /* ݡֹ */
+	  /* ポート番号入力 */
   entry_port = gtk_entry_new ();
   gtk_widget_ref (entry_port);
   gtk_object_set_data_full (GTK_OBJECT (netdlg), "entry_port", entry_port,
@@ -122,7 +126,7 @@ create_net_dialog(void)
   gtk_widget_show (hbox2);
   gtk_box_pack_end (GTK_BOX (dialog_action_area1), hbox2, TRUE, FALSE, 0);
 
-  button_ok = xpm_button_new(netdlg, ok_xpm, GT("OK")/*"λ"*/);
+  button_ok = xpm_button_new(netdlg, ok_xpm, GT("OK")/*"了解"*/);
   gtk_widget_ref (button_ok);
   gtk_object_set_data_full (GTK_OBJECT (netdlg), "button_ok", button_ok,
                             (GtkDestroyNotify) gtk_widget_unref);
@@ -130,7 +134,7 @@ create_net_dialog(void)
   gtk_widget_show (button_ok);
   gtk_box_pack_start (GTK_BOX (hbox2), button_ok, FALSE, FALSE, 0);
 
-  button_cancel = xpm_button_new(netdlg, ng_xpm, GT("Cancel")/*""*/);
+  button_cancel = xpm_button_new(netdlg, ng_xpm, GT("Cancel")/*"取消"*/);
   gtk_widget_ref (button_cancel);
   gtk_object_set_data_full (GTK_OBJECT (netdlg), "button_cancel", button_cancel,
                             (GtkDestroyNotify) gtk_widget_unref);
