@@ -1,6 +1,10 @@
 /**
- * ʣ̲
- * Copyright (c) 2004 Kagetani Hideto
+ * @file settingdlg.c
+ * @brief 設定ダイアログ
+ * @author BananaJinn
+ * @version $Id: settingdlg.c,v 1.8 2010/11/01 14:34:11 bananajinn Exp $
+ * 円盤複写屋
+ * Copyright (C) 2004-2010 BananaJinn<banana@mxh.mesh.ne.jp>
  */
 #include <stdlib.h>
 #include <string.h>
@@ -161,7 +165,7 @@ create_setting_dialog (void)
 
   setting_dlg = gtk_dialog_new ();
   gtk_object_set_data (GTK_OBJECT (setting_dlg), "setting_dlg", setting_dlg);
-  gtk_window_set_title (GTK_WINDOW (setting_dlg), GT("Setting")/*"ʣ"*/);
+  gtk_window_set_title (GTK_WINDOW (setting_dlg), GT("Setting")/*"複写設定"*/);
   /*GTK_WINDOW (setting_dlg)->type = GTK_WINDOW_DIALOG;*/
   gtk_window_set_position (GTK_WINDOW (setting_dlg), GTK_WIN_POS_CENTER);
   gtk_window_set_modal (GTK_WINDOW (setting_dlg), TRUE);
@@ -181,7 +185,7 @@ create_setting_dialog (void)
   gtk_table_set_row_spacings (GTK_TABLE (table1), 5);
   gtk_table_set_col_spacings (GTK_TABLE (table1), 5);
 
-  label_readspeed = gtk_label_new (GT("Read speed")/*"ɼ®"*/);
+  label_readspeed = gtk_label_new (GT("Read speed")/*"読取速度"*/);
   gtk_widget_ref (label_readspeed);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "label_readspeed",
 			    label_readspeed,
@@ -192,7 +196,7 @@ create_setting_dialog (void)
                     (GtkAttachOptions) (0), 0, 0);
   gtk_misc_set_alignment (GTK_MISC (label_readspeed), 0, 0.5);
 
-  label_writespeed = gtk_label_new (GT("Write speed")/*"Ͽ®"*/);
+  label_writespeed = gtk_label_new (GT("Write speed")/*"記録速度"*/);
   gtk_widget_ref (label_writespeed);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "label_writespeed",
 			    label_writespeed,
@@ -230,7 +234,7 @@ create_setting_dialog (void)
 			    optmenu_writespeed_menu);
 
   check_testwrite = gtk_check_button_new_with_label (GT("Test write")
-						     /*"Ͽ(TestWrite)"*/);
+						     /*"記録試験(TestWrite)"*/);
   gtk_widget_ref (check_testwrite);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "check_testwrite",
 			    check_testwrite,
@@ -241,7 +245,7 @@ create_setting_dialog (void)
                     (GtkAttachOptions) (0), 0, 0);
 
   check_bufe = gtk_check_button_new_with_label (GT("Buffer underrun free enable")
-						/*"®­(BufferUnderrunFreeEnable)"*/);
+						/*"速度不足回避(BufferUnderrunFreeEnable)"*/);
   gtk_widget_ref (check_bufe);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "check_bufe",
 			    check_bufe,
@@ -252,7 +256,7 @@ create_setting_dialog (void)
                     (GtkAttachOptions) (0), 0, 0);
 
   check_onthefly = gtk_check_button_new_with_label (GT("On the fly")
-						    /*"ľŪϿ(on-the-fly)"*/);
+						    /*"直接的記録(on-the-fly)"*/);
   gtk_widget_ref (check_onthefly);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "check_onthefly", check_onthefly,
                             (GtkDestroyNotify) gtk_widget_unref);
@@ -262,7 +266,7 @@ create_setting_dialog (void)
                     (GtkAttachOptions) (0), 0, 0);
 
   check_dao = gtk_check_button_new_with_label (GT("Disc at once")
-					       /*"ɮ(Disc-at-once)"*/);
+					       /*"一筆書き(Disc-at-once)"*/);
   gtk_widget_ref (check_dao);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "check_dao",
 			    check_dao,
@@ -273,7 +277,7 @@ create_setting_dialog (void)
                     (GtkAttachOptions) (0), 0, 0);
 
   check_outside = gtk_check_button_new_with_label (GT("Write to outside")
-						   /*"¦˵Ͽ"*/);
+						   /*"外側に記録"*/);
   gtk_widget_ref (check_outside);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "check_outside",
 			    check_outside,
@@ -284,7 +288,7 @@ create_setting_dialog (void)
                     (GtkAttachOptions) (0), 0, 0);
 
   label_temppath = gtk_label_new (GT("Temporary directory")
-				  /*"ǥ쥯ȥ"*/);
+				  /*"一時ディレクトリ"*/);
   gtk_widget_ref (label_temppath);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "label_temppath",
 			   label_temppath,
@@ -319,7 +323,7 @@ create_setting_dialog (void)
   gtk_widget_show (hbox1);
   gtk_box_pack_end (GTK_BOX (dialog_action_area1), hbox1, FALSE, FALSE, 0);
 
-  button_ok = xpm_button_new (setting_dlg, ok_xpm, GT("OK")/*""*/);
+  button_ok = xpm_button_new (setting_dlg, ok_xpm, GT("OK")/*"開始"*/);
   gtk_widget_ref (button_ok);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "button_ok",
 							button_ok,
@@ -328,7 +332,7 @@ create_setting_dialog (void)
   gtk_widget_show (button_ok);
   gtk_box_pack_start (GTK_BOX (hbox1), button_ok, FALSE, FALSE, 0);
 
-  button_cancel = xpm_button_new (setting_dlg, ng_xpm, GT("Cancel")/*""*/);
+  button_cancel = xpm_button_new (setting_dlg, ng_xpm, GT("Cancel")/*"取消"*/);
   gtk_widget_ref (button_cancel);
   gtk_object_set_data_full (GTK_OBJECT (setting_dlg), "button_cancel",
 			    button_cancel,
