@@ -1,7 +1,10 @@
-/* ʣ̲
- * Copyright (C) 2004 Kagetani Hideto
+/**
+ * @file ui.h
+ * @author BananaJinn
+ * @version $Id: ui.h,v 1.5 2010/11/01 14:34:11 bananajinn Exp $
+ * 円盤複写屋
+ * Copyright (C) 2004-2010 BananaJinn<banana@mxh.mesh.ne.jp>
  */
-
 #ifndef __UI_H__
 #define __UI_H__
 
@@ -26,6 +29,7 @@ extern void UIMeter1Update(float percentage);
 extern void UIMeter2Update(float percentage);
 extern void UIDispInfo(const char *message);
 extern int UIFileDialog(BOOL bOpen, char *filename, int size, const char *suffix);
+extern int UIFolderDialog(char *filename, int size);
 extern int UINetDialog(BOOL bServer, char *remote, int size, int *port_number);
 
 extern void UISetWidgetMeter1(GtkWidget *label, GtkWidget *progressbar);
