@@ -3,7 +3,7 @@ cd ../DriveAccess
 
 for fn in *.c *.h; do
   echo Converting $fn to sjis...
-  nkf -s -Lw $fn > tmp
+  nkf -s -Lu $fn > tmp
   mv tmp $fn
 done
 
