@@ -107,6 +107,7 @@ CEnbanFukusyaDlg::CEnbanFukusyaDlg(CWnd* pParent /*=NULL*/)
 	m_nWriteDriveISO = -1;
 	m_nReadDriveNet = -1;
 	m_nWriteDriveNet = -1;
+	m_nReadDriveMkisofs = -1;
 }
 
 void CEnbanFukusyaDlg::DoDataExchange(CDataExchange* pDX)
@@ -520,6 +521,9 @@ LRESULT CEnbanFukusyaDlg::OnKickIdle(WPARAM wParam, LPARAM lParam)
 	m_CmbWriter.AddString("lbg[N");
 	m_nWriteDriveNet = m_CmbWriter.GetCount()-1;
 
+	m_CmbReader.AddString("tH_ISOC[W(mkisofs)");
+	m_nReadDriveMkisofs = m_CmbReader.GetCount()-1;
+
 	/*
 	 * R}hCɂǎ摕uwmF
 	 */
@@ -681,7 +685,11 @@ void CEnbanFukusyaDlg::OnOK()
 		nWriter=1;
 	}
 	
-	if(sel_reader == m_nReadDriveISO){
+	if(sel_reader == m_nReadDriveMkisofs){
+		reader.hid = HID_VIRTUAL;
+		reader.tid = CMDDRVTYPE_MKISOFS;
+	}
+	else if(sel_reader == m_nReadDriveISO){
 		reader.hid = HID_VIRTUAL;
 		reader.tid = CMDDRVTYPE_ISO;
 	}
